@@ -272,6 +272,9 @@ public class Decision extends DRGElement implements DomainObject,
         if (fontSet != null ? !fontSet.equals(that.fontSet) : that.fontSet != null) {
             return false;
         }
+        if (linksHolder != null ? !linksHolder.equals(that.linksHolder) : that.linksHolder != null) {
+            return false;
+        }
         return dimensionsSet != null ? dimensionsSet.equals(that.dimensionsSet) : that.dimensionsSet == null;
     }
 
@@ -287,7 +290,8 @@ public class Decision extends DRGElement implements DomainObject,
                                          expression != null ? expression.hashCode() : 0,
                                          backgroundSet != null ? backgroundSet.hashCode() : 0,
                                          fontSet != null ? fontSet.hashCode() : 0,
-                                         dimensionsSet != null ? dimensionsSet.hashCode() : 0);
+                                         dimensionsSet != null ? dimensionsSet.hashCode() : 0,
+                                         linksHolder != null ? linksHolder.hashCode() : 0);
     }
 
     private void setVariableParent() {
