@@ -17,7 +17,7 @@
 package org.kie.workbench.common.dmn.client.editors.expressions.types.function.supplementary;
 
 import java.util.Collections;
-import java.util.List;
+import java.util.Objects;
 import java.util.Optional;
 import java.util.function.Supplier;
 
@@ -28,37 +28,45 @@ import org.jboss.errai.ui.client.local.spi.TranslationService;
 import org.kie.workbench.common.dmn.api.definition.HasExpression;
 import org.kie.workbench.common.dmn.api.definition.HasName;
 import org.kie.workbench.common.dmn.api.definition.v1_1.Context;
+import org.kie.workbench.common.dmn.api.definition.v1_1.ContextEntry;
+import org.kie.workbench.common.dmn.api.definition.v1_1.Expression;
+import org.kie.workbench.common.dmn.api.definition.v1_1.IsLiteralExpression;
+import org.kie.workbench.common.dmn.client.commands.factory.DefaultCanvasCommandFactory;
 import org.kie.workbench.common.dmn.client.editors.expressions.types.ExpressionEditorDefinitions;
-import org.kie.workbench.common.dmn.client.editors.expressions.types.context.ContextGridRenderer;
+import org.kie.workbench.common.dmn.client.editors.expressions.types.context.ContextGridRowNumberColumn;
 import org.kie.workbench.common.dmn.client.editors.expressions.types.context.ContextUIModelMapper;
+import org.kie.workbench.common.dmn.client.editors.expressions.types.context.ContextUIModelMapperHelper;
+import org.kie.workbench.common.dmn.client.editors.expressions.types.context.ExpressionCellValue;
 import org.kie.workbench.common.dmn.client.editors.expressions.types.context.ExpressionEditorColumn;
 import org.kie.workbench.common.dmn.client.widgets.grid.BaseExpressionGrid;
+import org.kie.workbench.common.dmn.client.widgets.grid.BaseExpressionGridRenderer;
 import org.kie.workbench.common.dmn.client.widgets.grid.controls.container.CellEditorControlsView;
 import org.kie.workbench.common.dmn.client.widgets.grid.controls.list.HasListSelectorControl;
 import org.kie.workbench.common.dmn.client.widgets.grid.controls.list.ListSelectorView;
-import org.kie.workbench.common.dmn.client.widgets.grid.model.DMNGridRow;
+import org.kie.workbench.common.dmn.client.widgets.grid.model.BaseUIModelMapper;
+import org.kie.workbench.common.dmn.client.widgets.grid.model.DMNGridColumn;
 import org.kie.workbench.common.dmn.client.widgets.grid.model.ExpressionEditorChanged;
+import org.kie.workbench.common.dmn.client.widgets.grid.model.ExpressionEditorGridRow;
 import org.kie.workbench.common.dmn.client.widgets.grid.model.GridCellTuple;
 import org.kie.workbench.common.dmn.client.widgets.layer.DMNGridLayer;
 import org.kie.workbench.common.dmn.client.widgets.panel.DMNGridPanel;
 import org.kie.workbench.common.stunner.core.client.api.SessionManager;
 import org.kie.workbench.common.stunner.core.client.canvas.AbstractCanvasHandler;
-import org.kie.workbench.common.stunner.core.client.command.CanvasCommandFactory;
+import org.kie.workbench.common.stunner.core.client.canvas.event.selection.DomainObjectSelectionEvent;
 import org.kie.workbench.common.stunner.core.client.command.SessionCommandManager;
 import org.kie.workbench.common.stunner.core.util.DefinitionUtils;
-import org.uberfire.ext.wires.core.grids.client.model.impl.BaseHeaderMetaData;
-import org.uberfire.ext.wires.core.grids.client.widget.grid.columns.RowNumberColumn;
+import org.kie.workbench.common.stunner.core.util.StringUtils;
+import org.kie.workbench.common.stunner.forms.client.event.RefreshFormPropertiesEvent;
+import org.uberfire.ext.wires.core.grids.client.model.GridCell;
+import org.uberfire.ext.wires.core.grids.client.model.GridData;
 
 public class FunctionSupplementaryGrid extends BaseExpressionGrid<Context, FunctionSupplementaryGridData, ContextUIModelMapper> implements HasListSelectorControl {
 
-    private static final String EXPRESSION_COLUMN_GROUP = "FunctionSupplementaryGrid$ExpressionColumn1";
-
     private final Supplier<ExpressionEditorDefinitions> expressionEditorDefinitionsSupplier;
 
     public FunctionSupplementaryGrid(final GridCellTuple parent,
                                      final Optional<String> nodeUUID,
                                      final HasExpression hasExpression,
-                                     final Optional<Context> expression,
                                      final Optional<HasName> hasName,
                                      final DMNGridPanel gridPanel,
                                      final DMNGridLayer gridLayer,
@@ -66,30 +74,35 @@ public class FunctionSupplementaryGrid extends BaseExpressionGrid<Context, Funct
                                      final DefinitionUtils definitionUtils,
                                      final SessionManager sessionManager,
                                      final SessionCommandManager<AbstractCanvasHandler> sessionCommandManager,
-                                     final CanvasCommandFactory<AbstractCanvasHandler> canvasCommandFactory,
+                                     final DefaultCanvasCommandFactory canvasCommandFactory,
                                      final Event<ExpressionEditorChanged> editorSelectedEvent,
+                                     final Event<RefreshFormPropertiesEvent> refreshFormPropertiesEvent,
+                                     final Event<DomainObjectSelectionEvent> domainObjectSelectionEvent,
                                      final CellEditorControlsView.Presenter cellEditorControls,
                                      final ListSelectorView.Presenter listSelector,
                                      final TranslationService translationService,
+                                     final boolean isOnlyVisualChangeAllowed,
                                      final int nesting,
                                      final Supplier<ExpressionEditorDefinitions> expressionEditorDefinitionsSupplier) {
         super(parent,
               nodeUUID,
               hasExpression,
-              expression,
               hasName,
               gridPanel,
               gridLayer,
               gridData,
-              new ContextGridRenderer(true),
+              new BaseExpressionGridRenderer(gridData),
               definitionUtils,
               sessionManager,
               sessionCommandManager,
               canvasCommandFactory,
               editorSelectedEvent,
+              refreshFormPropertiesEvent,
+              domainObjectSelectionEvent,
               cellEditorControls,
               listSelector,
               translationService,
+              isOnlyVisualChangeAllowed,
               nesting);
         this.expressionEditorDefinitionsSupplier = expressionEditorDefinitionsSupplier;
 
@@ -108,7 +121,8 @@ public class FunctionSupplementaryGrid extends BaseExpressionGrid<Context, Funct
     public ContextUIModelMapper makeUiModelMapper() {
         return new FunctionSupplementaryGridUIModelMapper(this,
                                                           this::getModel,
-                                                          () -> expression,
+                                                          getExpression(),
+                                                          () -> isOnlyVisualChangeAllowed,
                                                           expressionEditorDefinitionsSupplier,
                                                           listSelector,
                                                           nesting);
@@ -116,13 +130,16 @@ public class FunctionSupplementaryGrid extends BaseExpressionGrid<Context, Funct
 
     @Override
     public void initialiseUiColumns() {
-        final NameColumn nameColumn = new NameColumn(this);
+        final ContextGridRowNumberColumn rowNumberColumn = new ContextGridRowNumberColumn(Collections.emptyList(),
+                                                                                          getAndSetInitialWidth(0, ContextGridRowNumberColumn.DEFAULT_WIDTH));
+        final NameColumn nameColumn = new NameColumn(getAndSetInitialWidth(1, DMNGridColumn.DEFAULT_WIDTH),
+                                                     this);
         final ExpressionEditorColumn expressionColumn = new ExpressionEditorColumn(gridLayer,
-                                                                                   new BaseHeaderMetaData("",
-                                                                                                          EXPRESSION_COLUMN_GROUP),
+                                                                                   Collections.emptyList(),
+                                                                                   getAndSetInitialWidth(2, ExpressionEditorColumn.DEFAULT_WIDTH),
                                                                                    this);
 
-        model.appendColumn(new RowNumberColumn());
+        model.appendColumn(rowNumberColumn);
         model.appendColumn(nameColumn);
         model.appendColumn(expressionColumn);
 
@@ -130,33 +147,58 @@ public class FunctionSupplementaryGrid extends BaseExpressionGrid<Context, Funct
     }
 
     @Override
-    public void initialiseUiModel() {
-        expression.ifPresent(c -> {
-            c.getContextEntry().stream().forEach(ce -> {
-                model.appendRow(new DMNGridRow());
-                uiModelMapper.fromDMNModel(model.getRowCount() - 1,
-                                           0);
-                uiModelMapper.fromDMNModel(model.getRowCount() - 1,
-                                           1);
-                uiModelMapper.fromDMNModel(model.getRowCount() - 1,
-                                           2);
-            });
+    public void initialiseUiRows() {
+        getExpression().get().ifPresent(c -> {
+            c.getContextEntry().forEach(ce -> model.appendRow(new ExpressionEditorGridRow()));
         });
     }
 
     @Override
-    protected boolean isHeaderHidden() {
-        return true;
+    public void initialiseUiCells() {
+        getExpression().get().ifPresent(c -> {
+            for (int rowIndex = 0; rowIndex < c.getContextEntry().size(); rowIndex++) {
+                uiModelMapper.fromDMNModel(rowIndex,
+                                           0);
+                uiModelMapper.fromDMNModel(rowIndex,
+                                           1);
+                uiModelMapper.fromDMNModel(rowIndex,
+                                           2);
+            }
+        });
     }
 
-    @Override
-    public List<ListSelectorItem> getItems(final int uiRowIndex,
-                                           final int uiColumnIndex) {
-        return Collections.emptyList();
+    public String getExpressionValue(final String key) {
+        final Optional<Context> oContext = getExpression().get();
+        if (oContext.isPresent()) {
+            final Context context = oContext.get();
+            return context.getContextEntry()
+                    .stream()
+                    .filter(ce -> Objects.equals(key, ce.getVariable().getName().getValue()))
+                    .findFirst()
+                    .map(ContextEntry::getExpression)
+                    .filter(cee -> cee instanceof IsLiteralExpression)
+                    .map(cee -> (IsLiteralExpression) cee)
+                    .map(ile -> StringUtils.createUnquotedConstant(ile.getText().getValue()))
+                    .orElse("");
+        }
+        return "";
     }
 
-    @Override
-    public void onItemSelected(final ListSelectorItem item) {
-        //Do nothing for now until https://issues.jboss.org/browse/DROOLS-2298
+    public Optional<BaseExpressionGrid<? extends Expression, ? extends GridData, ? extends BaseUIModelMapper>> getExpressionValueEditor(final String key) {
+        final Optional<Context> oContext = getExpression().get();
+        if (oContext.isPresent()) {
+            final Context context = oContext.get();
+            return context.getContextEntry()
+                    .stream()
+                    .filter(ce -> Objects.equals(key, ce.getVariable().getName().getValue()))
+                    .findFirst()
+                    .map(ce -> context.getContextEntry().indexOf(ce))
+                    .map(rowIndex -> model.getCell(rowIndex, ContextUIModelMapperHelper.EXPRESSION_COLUMN_INDEX))
+                    .map(GridCell::getValue)
+                    .filter(value -> value instanceof ExpressionCellValue)
+                    .map(value -> (ExpressionCellValue) value)
+                    .flatMap(ExpressionCellValue::getValue);
+        }
+        return Optional.empty();
     }
 }
