@@ -17,7 +17,6 @@
 package org.kie.workbench.common.dmn.client.editors.expressions.types.invocation;
 
 import java.util.ArrayList;
-import java.util.Arrays;
 import java.util.List;
 import java.util.Optional;
 import java.util.function.Supplier;
@@ -29,51 +28,56 @@ import org.jboss.errai.ui.client.local.spi.TranslationService;
 import org.kie.workbench.common.dmn.api.definition.HasExpression;
 import org.kie.workbench.common.dmn.api.definition.HasName;
 import org.kie.workbench.common.dmn.api.definition.v1_1.Binding;
+import org.kie.workbench.common.dmn.api.definition.v1_1.DMNModelInstrumentedBase;
 import org.kie.workbench.common.dmn.api.definition.v1_1.InformationItem;
 import org.kie.workbench.common.dmn.api.definition.v1_1.Invocation;
 import org.kie.workbench.common.dmn.api.definition.v1_1.LiteralExpression;
 import org.kie.workbench.common.dmn.api.property.dmn.Name;
+import org.kie.workbench.common.dmn.api.property.dmn.Text;
 import org.kie.workbench.common.dmn.client.commands.expressions.types.invocation.AddParameterBindingCommand;
 import org.kie.workbench.common.dmn.client.commands.expressions.types.invocation.ClearExpressionTypeCommand;
 import org.kie.workbench.common.dmn.client.commands.expressions.types.invocation.DeleteParameterBindingCommand;
+import org.kie.workbench.common.dmn.client.commands.factory.DefaultCanvasCommandFactory;
 import org.kie.workbench.common.dmn.client.editors.expressions.types.ExpressionEditorDefinitions;
 import org.kie.workbench.common.dmn.client.editors.expressions.types.context.ExpressionCellValue;
 import org.kie.workbench.common.dmn.client.editors.expressions.types.context.ExpressionEditorColumn;
-import org.kie.workbench.common.dmn.client.editors.expressions.types.context.NameColumnHeaderMetaData;
+import org.kie.workbench.common.dmn.client.editors.expressions.types.undefined.UndefinedExpressionColumn;
 import org.kie.workbench.common.dmn.client.editors.expressions.types.undefined.UndefinedExpressionGrid;
 import org.kie.workbench.common.dmn.client.editors.expressions.util.SelectionUtils;
+import org.kie.workbench.common.dmn.client.editors.types.NameAndDataTypePopoverView;
 import org.kie.workbench.common.dmn.client.resources.i18n.DMNEditorConstants;
 import org.kie.workbench.common.dmn.client.widgets.grid.BaseExpressionGrid;
 import org.kie.workbench.common.dmn.client.widgets.grid.controls.container.CellEditorControlsView;
 import org.kie.workbench.common.dmn.client.widgets.grid.controls.list.HasListSelectorControl;
 import org.kie.workbench.common.dmn.client.widgets.grid.controls.list.ListSelectorView;
-import org.kie.workbench.common.dmn.client.widgets.grid.model.DMNGridRow;
+import org.kie.workbench.common.dmn.client.widgets.grid.model.DMNGridColumn;
 import org.kie.workbench.common.dmn.client.widgets.grid.model.ExpressionEditorChanged;
+import org.kie.workbench.common.dmn.client.widgets.grid.model.ExpressionEditorGridRow;
 import org.kie.workbench.common.dmn.client.widgets.grid.model.GridCellTuple;
 import org.kie.workbench.common.dmn.client.widgets.layer.DMNGridLayer;
 import org.kie.workbench.common.dmn.client.widgets.panel.DMNGridPanel;
 import org.kie.workbench.common.stunner.core.client.api.SessionManager;
 import org.kie.workbench.common.stunner.core.client.canvas.AbstractCanvasHandler;
-import org.kie.workbench.common.stunner.core.client.command.CanvasCommandFactory;
+import org.kie.workbench.common.stunner.core.client.canvas.event.selection.DomainObjectSelectionEvent;
 import org.kie.workbench.common.stunner.core.client.command.CanvasViolation;
 import org.kie.workbench.common.stunner.core.client.command.SessionCommandManager;
 import org.kie.workbench.common.stunner.core.command.CommandResult;
 import org.kie.workbench.common.stunner.core.command.util.CommandUtils;
+import org.kie.workbench.common.stunner.core.domainobject.DomainObject;
 import org.kie.workbench.common.stunner.core.util.DefinitionUtils;
+import org.kie.workbench.common.stunner.forms.client.event.RefreshFormPropertiesEvent;
 import org.uberfire.ext.wires.core.grids.client.model.GridCell;
-import org.uberfire.ext.wires.core.grids.client.model.impl.BaseHeaderMetaData;
+import org.uberfire.ext.wires.core.grids.client.model.GridColumn;
 import org.uberfire.ext.wires.core.grids.client.widget.grid.columns.RowNumberColumn;
 
 public class InvocationGrid extends BaseExpressionGrid<Invocation, InvocationGridData, InvocationUIModelMapper> implements HasListSelectorControl {
 
-    private static final String EXPRESSION_COLUMN_GROUP = "InvocationGrid$ExpressionColumn1";
-
     private final Supplier<ExpressionEditorDefinitions> expressionEditorDefinitionsSupplier;
+    private final NameAndDataTypePopoverView.Presenter headerEditor;
 
     public InvocationGrid(final GridCellTuple parent,
                           final Optional<String> nodeUUID,
                           final HasExpression hasExpression,
-                          final Optional<Invocation> expression,
                           final Optional<HasName> hasName,
                           final DMNGridPanel gridPanel,
                           final DMNGridLayer gridLayer,
@@ -81,32 +85,39 @@ public class InvocationGrid extends BaseExpressionGrid<Invocation, InvocationGri
                           final DefinitionUtils definitionUtils,
                           final SessionManager sessionManager,
                           final SessionCommandManager<AbstractCanvasHandler> sessionCommandManager,
-                          final CanvasCommandFactory<AbstractCanvasHandler> canvasCommandFactory,
+                          final DefaultCanvasCommandFactory canvasCommandFactory,
                           final Event<ExpressionEditorChanged> editorSelectedEvent,
+                          final Event<RefreshFormPropertiesEvent> refreshFormPropertiesEvent,
+                          final Event<DomainObjectSelectionEvent> domainObjectSelectionEvent,
                           final CellEditorControlsView.Presenter cellEditorControls,
                           final ListSelectorView.Presenter listSelector,
                           final TranslationService translationService,
+                          final boolean isOnlyVisualChangeAllowed,
                           final int nesting,
-                          final Supplier<ExpressionEditorDefinitions> expressionEditorDefinitionsSupplier) {
+                          final Supplier<ExpressionEditorDefinitions> expressionEditorDefinitionsSupplier,
+                          final NameAndDataTypePopoverView.Presenter headerEditor) {
         super(parent,
               nodeUUID,
               hasExpression,
-              expression,
               hasName,
               gridPanel,
               gridLayer,
               gridData,
-              new InvocationGridRenderer(nesting > 0),
+              new InvocationGridRenderer(gridData),
               definitionUtils,
               sessionManager,
               sessionCommandManager,
               canvasCommandFactory,
               editorSelectedEvent,
+              refreshFormPropertiesEvent,
+              domainObjectSelectionEvent,
               cellEditorControls,
               listSelector,
               translationService,
+              isOnlyVisualChangeAllowed,
               nesting);
         this.expressionEditorDefinitionsSupplier = expressionEditorDefinitionsSupplier;
+        this.headerEditor = headerEditor;
 
         setEventPropagationMode(EventPropagationMode.NO_ANCESTORS);
 
@@ -123,7 +134,8 @@ public class InvocationGrid extends BaseExpressionGrid<Invocation, InvocationGri
     public InvocationUIModelMapper makeUiModelMapper() {
         return new InvocationUIModelMapper(this,
                                            this::getModel,
-                                           () -> expression,
+                                           getExpression(),
+                                           () -> isOnlyVisualChangeAllowed,
                                            expressionEditorDefinitionsSupplier,
                                            listSelector,
                                            nesting);
@@ -131,22 +143,47 @@ public class InvocationGrid extends BaseExpressionGrid<Invocation, InvocationGri
 
     @Override
     protected void initialiseUiColumns() {
-        final InvocationColumnExpressionHeaderMetaData expressionHeaderMetaData = new InvocationColumnExpressionHeaderMetaData(this::getExpressionText,
-                                                                                                                               this::setExpressionText,
-                                                                                                                               getHeaderTextBoxFactory());
-        final NameColumn nameColumn = new NameColumn(Arrays.asList(new NameColumnHeaderMetaData(() -> hasName.orElse(HasName.NOP).getName().getValue(),
-                                                                                                (s) -> hasName.orElse(HasName.NOP).getName().setValue(s),
-                                                                                                getHeaderHasNameTextBoxFactory()),
-                                                                   expressionHeaderMetaData),
-                                                     getBodyTextBoxFactory(),
-                                                     this);
+        final List<GridColumn.HeaderMetaData> headerMetaData = new ArrayList<>();
+        final RowNumberColumn rowNumberColumn = new RowNumberColumn();
+        rowNumberColumn.setWidth(getAndSetInitialWidth(0, rowNumberColumn.getWidth()));
+
+        if (nesting == 0) {
+            headerMetaData.add(new InvocationColumnHeaderMetaData(hasExpression,
+                                                                  hasName,
+                                                                  clearDisplayNameConsumer(true),
+                                                                  setDisplayNameConsumer(true),
+                                                                  setTypeRefConsumer(),
+                                                                  cellEditorControls,
+                                                                  headerEditor,
+                                                                  Optional.of(translationService.getTranslation(DMNEditorConstants.InvocationEditor_EditExpression)),
+                                                                  listSelector,
+                                                                  this::getHeaderItems,
+                                                                  this::onItemSelected));
+        }
+        headerMetaData.add(new InvocationColumnExpressionHeaderMetaData(this::getExpressionText,
+                                                                        this::setExpressionText,
+                                                                        getHeaderTextBoxFactory(),
+                                                                        Optional.of(translationService.getTranslation(DMNEditorConstants.InvocationEditor_EnterFunction)),
+                                                                        listSelector,
+                                                                        this::getHeaderItems,
+                                                                        this::onItemSelected));
+
+        final InvocationParameterColumn nameColumn = new InvocationParameterColumn(headerMetaData,
+                                                                                   getAndSetInitialWidth(1, DMNGridColumn.DEFAULT_WIDTH),
+                                                                                   this,
+                                                                                   rowIndex -> true,
+                                                                                   clearDisplayNameConsumer(false),
+                                                                                   setDisplayNameConsumer(false),
+                                                                                   setTypeRefConsumer(),
+                                                                                   cellEditorControls,
+                                                                                   headerEditor,
+                                                                                   Optional.of(translationService.getTranslation(DMNEditorConstants.InvocationEditor_EditParameter)));
         final ExpressionEditorColumn expressionColumn = new ExpressionEditorColumn(gridLayer,
-                                                                                   Arrays.asList(new BaseHeaderMetaData("",
-                                                                                                                        EXPRESSION_COLUMN_GROUP),
-                                                                                                 expressionHeaderMetaData),
+                                                                                   headerMetaData,
+                                                                                   getAndSetInitialWidth(2, UndefinedExpressionColumn.DEFAULT_WIDTH),
                                                                                    this);
 
-        model.appendColumn(new RowNumberColumn());
+        model.appendColumn(rowNumberColumn);
         model.appendColumn(nameColumn);
         model.appendColumn(expressionColumn);
 
@@ -154,31 +191,51 @@ public class InvocationGrid extends BaseExpressionGrid<Invocation, InvocationGri
     }
 
     private String getExpressionText() {
-        return ((LiteralExpression) expression.get().getExpression()).getText();
+        return getExpression().get().map(invocation -> (LiteralExpression) invocation.getExpression())
+                .map(LiteralExpression::getText)
+                .orElse(new Text())
+                .getValue();
     }
 
     private void setExpressionText(final String text) {
-        ((LiteralExpression) expression.get().getExpression()).setText(text);
+        getExpression().get().ifPresent(invocation -> ((LiteralExpression) invocation.getExpression()).getText().setValue(text));
     }
 
     @Override
-    protected void initialiseUiModel() {
-        expression.ifPresent(invocation -> {
-            invocation.getBinding().stream().forEach(binding -> {
-                model.appendRow(new DMNGridRow());
-                uiModelMapper.fromDMNModel(model.getRowCount() - 1,
-                                           InvocationUIModelMapper.ROW_NUMBER_COLUMN_INDEX);
-                uiModelMapper.fromDMNModel(model.getRowCount() - 1,
-                                           InvocationUIModelMapper.BINDING_PARAMETER_COLUMN_INDEX);
-                uiModelMapper.fromDMNModel(model.getRowCount() - 1,
-                                           InvocationUIModelMapper.BINDING_EXPRESSION_COLUMN_INDEX);
-            });
+    public void initialiseUiRows() {
+        getExpression().get().ifPresent(invocation -> {
+            invocation.getBinding().forEach(binding -> model.appendRow(new ExpressionEditorGridRow()));
         });
     }
 
     @Override
-    protected boolean isHeaderHidden() {
-        return false;
+    public void initialiseUiCells() {
+        getExpression().get().ifPresent(invocation -> {
+            for (int rowIndex = 0; rowIndex < invocation.getBinding().size(); rowIndex++) {
+                uiModelMapper.fromDMNModel(rowIndex,
+                                           InvocationUIModelMapper.ROW_NUMBER_COLUMN_INDEX);
+                uiModelMapper.fromDMNModel(rowIndex,
+                                           InvocationUIModelMapper.BINDING_PARAMETER_COLUMN_INDEX);
+                uiModelMapper.fromDMNModel(rowIndex,
+                                           InvocationUIModelMapper.BINDING_EXPRESSION_COLUMN_INDEX);
+            }
+        });
+    }
+
+    @SuppressWarnings("unused")
+    List<ListSelectorItem> getHeaderItems(final int uiHeaderRowIndex,
+                                          final int uiHeaderColumnIndex) {
+        final List<ListSelectorItem> items = new ArrayList<>();
+
+        items.add(ListSelectorHeaderItem.build(translationService.format(DMNEditorConstants.InvocationEditor_Header)));
+        items.add(ListSelectorTextItem.build(translationService.format(DMNEditorConstants.InvocationEditor_InsertParameter),
+                                             true,
+                                             () -> {
+                                                 cellEditorControls.hide();
+                                                 getExpression().get().ifPresent(e -> addParameterBinding(model.getRowCount()));
+                                             }));
+
+        return items;
     }
 
     @Override
@@ -189,17 +246,18 @@ public class InvocationGrid extends BaseExpressionGrid<Invocation, InvocationGri
         final boolean isMultiRow = SelectionUtils.isMultiRow(model);
         final boolean isMultiSelect = SelectionUtils.isMultiSelect(model);
 
+        items.add(ListSelectorHeaderItem.build(translationService.format(DMNEditorConstants.InvocationEditor_Header)));
         items.add(ListSelectorTextItem.build(translationService.format(DMNEditorConstants.InvocationEditor_InsertParameterAbove),
                                              !isMultiRow,
                                              () -> {
                                                  cellEditorControls.hide();
-                                                 expression.ifPresent(e -> addParameterBinding(uiRowIndex));
+                                                 getExpression().get().ifPresent(e -> addParameterBinding(uiRowIndex));
                                              }));
         items.add(ListSelectorTextItem.build(translationService.format(DMNEditorConstants.InvocationEditor_InsertParameterBelow),
                                              !isMultiRow,
                                              () -> {
                                                  cellEditorControls.hide();
-                                                 expression.ifPresent(e -> addParameterBinding(uiRowIndex + 1));
+                                                 getExpression().get().ifPresent(e -> addParameterBinding(uiRowIndex + 1));
                                              }));
         items.add(ListSelectorTextItem.build(translationService.format(DMNEditorConstants.InvocationEditor_DeleteParameter),
                                              !isMultiRow && model.getRowCount() > 1,
@@ -242,7 +300,7 @@ public class InvocationGrid extends BaseExpressionGrid<Invocation, InvocationGri
     }
 
     void addParameterBinding(final int index) {
-        expression.ifPresent(invocation -> {
+        getExpression().get().ifPresent(invocation -> {
             final Binding binding = new Binding();
             final InformationItem parameter = new InformationItem();
             parameter.setName(new Name());
@@ -252,10 +310,10 @@ public class InvocationGrid extends BaseExpressionGrid<Invocation, InvocationGri
                                                                                         new AddParameterBindingCommand(invocation,
                                                                                                                        binding,
                                                                                                                        model,
-                                                                                                                       new DMNGridRow(),
+                                                                                                                       new ExpressionEditorGridRow(),
                                                                                                                        index,
                                                                                                                        uiModelMapper,
-                                                                                                                       this::resize));
+                                                                                                                       () -> resize(BaseExpressionGrid.RESIZE_EXISTING)));
 
             if (!CommandUtils.isError(result)) {
                 selectCell(index, InvocationUIModelMapper.BINDING_PARAMETER_COLUMN_INDEX, false, false);
@@ -265,12 +323,12 @@ public class InvocationGrid extends BaseExpressionGrid<Invocation, InvocationGri
     }
 
     void deleteParameterBinding(final int index) {
-        expression.ifPresent(invocation -> {
+        getExpression().get().ifPresent(invocation -> {
             sessionCommandManager.execute((AbstractCanvasHandler) sessionManager.getCurrentSession().getCanvasHandler(),
                                           new DeleteParameterBindingCommand(invocation,
                                                                             model,
                                                                             index,
-                                                                            this::resize));
+                                                                            () -> resize(BaseExpressionGrid.RESIZE_EXISTING)));
         });
     }
 
@@ -278,12 +336,53 @@ public class InvocationGrid extends BaseExpressionGrid<Invocation, InvocationGri
         final GridCellTuple gc = new GridCellTuple(uiRowIndex,
                                                    InvocationUIModelMapper.BINDING_EXPRESSION_COLUMN_INDEX,
                                                    this);
-        final HasExpression hasExpression = expression.get().getBinding().get(uiRowIndex);
-        sessionCommandManager.execute((AbstractCanvasHandler) sessionManager.getCurrentSession().getCanvasHandler(),
-                                      new ClearExpressionTypeCommand(gc,
-                                                                     hasExpression,
-                                                                     uiModelMapper,
-                                                                     () -> resizeBasedOnCellExpressionEditor(uiRowIndex,
-                                                                                                             InvocationUIModelMapper.BINDING_EXPRESSION_COLUMN_INDEX)));
+        getExpression().get().ifPresent(invocation -> {
+            final HasExpression hasExpression = invocation.getBinding().get(uiRowIndex);
+            sessionCommandManager.execute((AbstractCanvasHandler) sessionManager.getCurrentSession().getCanvasHandler(),
+                                          new ClearExpressionTypeCommand(gc,
+                                                                         hasExpression,
+                                                                         uiModelMapper,
+                                                                         () -> {
+                                                                             resize(BaseExpressionGrid.RESIZE_EXISTING_MINIMUM);
+                                                                             selectExpressionEditorFirstCell(uiRowIndex, InvocationUIModelMapper.BINDING_EXPRESSION_COLUMN_INDEX);
+                                                                         },
+                                                                         () -> {
+                                                                             resize(BaseExpressionGrid.RESIZE_EXISTING_MINIMUM);
+                                                                             selectExpressionEditorFirstCell(uiRowIndex, InvocationUIModelMapper.BINDING_EXPRESSION_COLUMN_INDEX);
+                                                                         }));
+        });
+    }
+
+    @Override
+    public void doAfterSelectionChange(final int uiRowIndex,
+                                       final int uiColumnIndex) {
+        if (hasAnyHeaderCellSelected() || hasMultipleCellsSelected()) {
+            super.doAfterSelectionChange(uiRowIndex, uiColumnIndex);
+            return;
+        }
+
+        if (uiColumnIndex == InvocationUIModelMapper.BINDING_PARAMETER_COLUMN_INDEX) {
+            if (getExpression().get().isPresent()) {
+                final Invocation invocation = getExpression().get().get();
+                fireDomainObjectSelectionEvent(invocation.getBinding().get(uiRowIndex).getVariable());
+                return;
+            }
+        }
+        super.doAfterSelectionChange(uiRowIndex, uiColumnIndex);
+    }
+
+    @Override
+    public void doAfterHeaderSelectionChange(final int uiHeaderRowIndex,
+                                             final int uiHeaderColumnIndex) {
+        if (nesting == 0 && uiHeaderRowIndex == 0) {
+            if (uiHeaderColumnIndex == InvocationUIModelMapper.BINDING_PARAMETER_COLUMN_INDEX || uiHeaderColumnIndex == InvocationUIModelMapper.BINDING_EXPRESSION_COLUMN_INDEX) {
+                final DMNModelInstrumentedBase base = hasExpression.asDMNModelInstrumentedBase();
+                if (base instanceof DomainObject) {
+                    fireDomainObjectSelectionEvent((DomainObject) base);
+                    return;
+                }
+            }
+        }
+        super.doAfterHeaderSelectionChange(uiHeaderRowIndex, uiHeaderColumnIndex);
     }
 }
