@@ -88,6 +88,7 @@ public class UndefinedExpressionGrid extends BaseDelegatingExpressionGrid<Expres
                                    final CellEditorControlsView.Presenter cellEditorControls,
                                    final ListSelectorView.Presenter listSelector,
                                    final TranslationService translationService,
+                                   final boolean isOnlyVisualChangeAllowed,
                                    final int nesting,
                                    final UndefinedExpressionSelectorPopoverView.Presenter undefinedExpressionSelector,
                                    final Supplier<ExpressionEditorDefinitions> expressionEditorDefinitionsSupplier,
@@ -110,6 +111,7 @@ public class UndefinedExpressionGrid extends BaseDelegatingExpressionGrid<Expres
               cellEditorControls,
               listSelector,
               translationService,
+              isOnlyVisualChangeAllowed,
               nesting);
         this.undefinedExpressionSelector = undefinedExpressionSelector;
         this.expressionEditorDefinitionsSupplier = expressionEditorDefinitionsSupplier;
@@ -124,7 +126,7 @@ public class UndefinedExpressionGrid extends BaseDelegatingExpressionGrid<Expres
     }
 
     @Override
-    protected List<NodeMouseEventHandler> getNodeMouseClickEventHandlers(final GridSelectionManager selectionManager) {
+    public List<NodeMouseEventHandler> getNodeMouseClickEventHandlers(final GridSelectionManager selectionManager) {
         final List<NodeMouseEventHandler> handlers = new ArrayList<>();
         handlers.add(new DelegatingGridWidgetCellSelectorMouseEventHandler(selectionManager,
                                                                            this::getParentInformation,
@@ -135,8 +137,8 @@ public class UndefinedExpressionGrid extends BaseDelegatingExpressionGrid<Expres
     }
 
     @Override
-    protected List<NodeMouseEventHandler> getNodeMouseDoubleClickEventHandlers(final GridSelectionManager selectionManager,
-                                                                               final GridPinnedModeManager pinnedModeManager) {
+    public List<NodeMouseEventHandler> getNodeMouseDoubleClickEventHandlers(final GridSelectionManager selectionManager,
+                                                                            final GridPinnedModeManager pinnedModeManager) {
         return Collections.emptyList();
     }
 
@@ -169,8 +171,12 @@ public class UndefinedExpressionGrid extends BaseDelegatingExpressionGrid<Expres
     }
 
     @Override
-    protected void initialiseUiModel() {
+    public void initialiseUiRows() {
         model.appendRow(new ExpressionEditorGridRow());
+    }
+
+    @Override
+    public void initialiseUiCells() {
         uiModelMapper.fromDMNModel(0,
                                    0);
     }
@@ -222,6 +228,7 @@ public class UndefinedExpressionGrid extends BaseDelegatingExpressionGrid<Expres
                                                                                                 nodeUUID,
                                                                                                 hasExpression,
                                                                                                 hasName,
+                                                                                                isOnlyVisualChangeAllowed,
                                                                                                 nesting);
                                                                       }
                                                                       return editor;
