@@ -406,6 +406,33 @@ public class DMNEditorConstants {
     @TranslationKey(defaultValue = "")
     public static final String DMNDocumentationI18n_DiagramDoesNotHaveElements = "DMNDocumentationI18n.DiagramDoesNotHaveElements";
 
+    @TranslationKey(defaultValue = "")
+    public static final String DMNDocumentationI18n_Add = "DMNDocumentationI18n.Add";
+
+    @TranslationKey(defaultValue = "")
+    public static final String DMNDocumentationI18n_None = "DMNDocumentationI18n.None";
+
+    @TranslationKey(defaultValue = "")
+    public static final String DMNDocumentationI18n_Name = "DMNDocumentationI18n.Name";
+
+    @TranslationKey(defaultValue = "")
+    public static final String DMNDocumentationI18n_NamePlaceholder = "DMNDocumentationI18n.NamePlaceholder";
+
+    @TranslationKey(defaultValue = "")
+    public static final String DMNDocumentationI18n_Ok = "DMNDocumentationI18n.Ok";
+
+    @TranslationKey(defaultValue = "")
+    public static final String DMNDocumentationI18n_Cancel = "DMNDocumentationI18n.Cancel";
+
+    @TranslationKey(defaultValue = "")
+    public static final String DMNDocumentationI18n_AttachmentTip = "DMNDocumentationI18n.AttachmentTip";
+
+    @TranslationKey(defaultValue = "")
+    public static final String DMNDocumentationI18n_URL = "DMNDocumentationI18n.URL";
+
+    @TranslationKey(defaultValue = "")
+    public static final String DMNDocumentationI18n_URLPlaceholder = "DMNDocumentationI18n.URLPlaceholder";
+
     @TranslationKey(defaultValue = "")
     public static final String DMNDocumentationFactory_NoFileName = "DMNDocumentationFactory.NoFileName";
 
