@@ -47,6 +47,7 @@ import org.kie.workbench.common.dmn.client.commands.general.SetHeaderValueComman
 import org.kie.workbench.common.dmn.client.commands.general.SetTypeRefCommand;
 import org.kie.workbench.common.dmn.client.editors.expressions.types.context.ExpressionCellValue;
 import org.kie.workbench.common.dmn.client.widgets.grid.columns.EditableHeaderMetaData;
+import org.kie.workbench.common.dmn.client.widgets.grid.columns.factory.ListBoxSingletonDOMElementFactory;
 import org.kie.workbench.common.dmn.client.widgets.grid.columns.factory.TextAreaSingletonDOMElementFactory;
 import org.kie.workbench.common.dmn.client.widgets.grid.columns.factory.TextBoxSingletonDOMElementFactory;
 import org.kie.workbench.common.dmn.client.widgets.grid.controls.container.CellEditorControlsView;
@@ -124,6 +125,7 @@ public abstract class BaseExpressionGrid<E extends Expression, D extends GridDat
                               final CellEditorControlsView.Presenter cellEditorControls,
                               final ListSelectorView.Presenter listSelector,
                               final TranslationService translationService,
+                              final boolean isOnlyVisualChangeAllowed,
                               final int nesting) {
         super(nodeUUID,
               hasExpression,
@@ -137,7 +139,8 @@ public abstract class BaseExpressionGrid<E extends Expression, D extends GridDat
               refreshFormPropertiesEvent,
               domainObjectSelectionEvent,
               cellEditorControls,
-              translationService);
+              translationService,
+              isOnlyVisualChangeAllowed);
         this.parent = parent;
         this.gridPanel = gridPanel;
         this.definitionUtils = definitionUtils;
@@ -152,14 +155,17 @@ public abstract class BaseExpressionGrid<E extends Expression, D extends GridDat
         this.uiModelMapper = makeUiModelMapper();
 
         initialiseUiColumns();
-        initialiseUiModel();
+        initialiseUiRows();
+        initialiseUiCells();
     }
 
     protected abstract M makeUiModelMapper();
 
     protected abstract void initialiseUiColumns();
 
-    protected abstract void initialiseUiModel();
+    protected abstract void initialiseUiRows();
+
+    public abstract void initialiseUiCells();
 
     @SuppressWarnings("unchecked")
     public Consumer<HasName> clearDisplayNameConsumer(final boolean updateStunnerTitle) {
@@ -246,6 +252,16 @@ public abstract class BaseExpressionGrid<E extends Expression, D extends GridDat
                                                       newCellHasValueCommand());
     }
 
+    public ListBoxSingletonDOMElementFactory getBodyListBoxFactory() {
+        return new ListBoxSingletonDOMElementFactory(gridPanel,
+                                                     gridLayer,
+                                                     this,
+                                                     sessionManager,
+                                                     sessionCommandManager,
+                                                     newCellHasNoValueCommand(),
+                                                     newCellHasValueCommand());
+    }
+
     protected Function<GridCellTuple, Command> newCellHasNoValueCommand() {
         return (gridCellTuple) -> new DeleteCellValueCommand(gridCellTuple,
                                                              () -> uiModelMapper,
@@ -305,7 +321,7 @@ public abstract class BaseExpressionGrid<E extends Expression, D extends GridDat
     }
 
     @Override
-    protected List<NodeMouseEventHandler> getNodeMouseClickEventHandlers(final GridSelectionManager selectionManager) {
+    public List<NodeMouseEventHandler> getNodeMouseClickEventHandlers(final GridSelectionManager selectionManager) {
         final List<NodeMouseEventHandler> handlers = new ArrayList<>();
         handlers.add(new DefaultGridWidgetCellSelectorMouseEventHandler(selectionManager));
         handlers.add(new EditableHeaderGridWidgetEditCellMouseEventHandler());
@@ -313,8 +329,8 @@ public abstract class BaseExpressionGrid<E extends Expression, D extends GridDat
     }
 
     @Override
-    protected List<NodeMouseEventHandler> getNodeMouseDoubleClickEventHandlers(final GridSelectionManager selectionManager,
-                                                                               final GridPinnedModeManager pinnedModeManager) {
+    public List<NodeMouseEventHandler> getNodeMouseDoubleClickEventHandlers(final GridSelectionManager selectionManager,
+                                                                            final GridPinnedModeManager pinnedModeManager) {
         final List<NodeMouseEventHandler> handlers = new ArrayList<>();
         handlers.add(new EditableHeaderGridWidgetEditCellMouseEventHandler());
         return handlers;
@@ -325,6 +341,10 @@ public abstract class BaseExpressionGrid<E extends Expression, D extends GridDat
         return false;
     }
 
+    public DMNGridPanel getGridPanel() {
+        return gridPanel;
+    }
+
     @Override
     public Viewport getViewport() {
         // A GridWidget's Viewport may not have been set IF the grid has not been attached to a Layer.
@@ -384,11 +404,6 @@ public abstract class BaseExpressionGrid<E extends Expression, D extends GridDat
         return true;
     }
 
-    //Package protected getter for Unit Tests.
-    Optional<String> getNodeUUID() {
-        return nodeUUID;
-    }
-
     public double getMinimumWidth() {
         double minimumWidth = 0;
         final int columnCount = model.getColumnCount();
@@ -407,23 +422,24 @@ public abstract class BaseExpressionGrid<E extends Expression, D extends GridDat
         doResize(new GridLayerRedrawManager.PrioritizedCommand(0) {
                      @Override
                      public void execute() {
-                         gridLayer.draw();
+                         getLayer().draw();
                      }
                  },
                  requiredWidthSupplier);
     }
 
-    protected void doResize(final GridLayerRedrawManager.PrioritizedCommand command,
-                            final Function<BaseExpressionGrid, Double> requiredWidthSupplier) {
+    public void doResize(final GridLayerRedrawManager.PrioritizedCommand command,
+                         final Function<BaseExpressionGrid, Double> requiredWidthSupplier) {
         final double proposedWidth = getWidth() + getPadding() * 2;
-        parent.proposeContainingColumnWidth(proposedWidth, requiredWidthSupplier);
+        getParentInformation().proposeContainingColumnWidth(proposedWidth, requiredWidthSupplier);
 
-        gridPanel.refreshScrollPosition();
-        gridPanel.updatePanelSize();
-        gridPanel.setFocus(true);
-        parent.onResize();
+        getGridPanel().refreshScrollPosition();
+        getGridPanel().updatePanelSize();
+        getGridPanel().setFocus(true);
+        getParentInformation().onResize();
 
-        gridLayer.batch(command);
+        //This cast is safe as the constructor expects a DMNGridLayer.
+        ((DMNGridLayer) getLayer()).batch(command);
     }
 
     public void selectFirstCell() {
