@@ -31,11 +31,11 @@ import org.kie.workbench.common.dmn.client.editors.expressions.types.context.Con
 import org.kie.workbench.common.dmn.client.editors.expressions.types.context.ContextUIModelMapper;
 import org.kie.workbench.common.dmn.client.editors.expressions.types.context.ExpressionCellValue;
 import org.kie.workbench.common.dmn.client.editors.expressions.types.context.ExpressionEditorColumn;
+import org.kie.workbench.common.dmn.client.editors.expressions.types.context.InformationItemCell;
 import org.kie.workbench.common.dmn.client.editors.expressions.types.context.NameColumn;
 import org.kie.workbench.common.dmn.client.editors.expressions.types.undefined.UndefinedExpressionEditorDefinition;
 import org.kie.workbench.common.dmn.client.widgets.grid.BaseExpressionGrid;
 import org.kie.workbench.common.dmn.client.widgets.grid.controls.list.ListSelectorView;
-import org.kie.workbench.common.dmn.client.widgets.grid.model.DMNGridRow;
 import org.kie.workbench.common.dmn.client.widgets.grid.model.GridCellTuple;
 import org.kie.workbench.common.stunner.core.client.canvas.AbstractCanvasHandler;
 import org.kie.workbench.common.stunner.core.client.command.CanvasCommandResultBuilder;
@@ -48,7 +48,9 @@ import org.kie.workbench.common.stunner.core.rule.RuleViolation;
 import org.mockito.Mock;
 import org.mockito.runners.MockitoJUnitRunner;
 import org.uberfire.ext.wires.core.grids.client.model.GridData;
+import org.uberfire.ext.wires.core.grids.client.model.GridRow;
 import org.uberfire.ext.wires.core.grids.client.model.impl.BaseGridData;
+import org.uberfire.ext.wires.core.grids.client.model.impl.BaseGridRow;
 import org.uberfire.ext.wires.core.grids.client.widget.grid.GridWidget;
 import org.uberfire.ext.wires.core.grids.client.widget.grid.columns.RowNumberColumn;
 
@@ -56,6 +58,7 @@ import static org.junit.Assert.assertEquals;
 import static org.junit.Assert.assertNull;
 import static org.junit.Assert.assertTrue;
 import static org.mockito.Matchers.any;
+import static org.mockito.Matchers.anyBoolean;
 import static org.mockito.Matchers.anyInt;
 import static org.mockito.Mockito.doReturn;
 import static org.mockito.Mockito.reset;
@@ -110,9 +113,9 @@ public class AddContextEntryCommandTest {
 
     private GridData uiModel;
 
-    private DMNGridRow uiModelRow;
+    private GridRow uiModelRow;
 
-    private DMNGridRow uiDefaultResultModelRow;
+    private GridRow uiDefaultResultModelRow;
 
     private ContextUIModelMapper uiModelMapper;
 
@@ -133,8 +136,8 @@ public class AddContextEntryCommandTest {
         this.defaultResultContextEntry = new ContextEntry();
         this.context.getContextEntry().add(defaultResultContextEntry);
         this.uiModel = new BaseGridData();
-        this.uiModelRow = new DMNGridRow();
-        this.uiDefaultResultModelRow = new DMNGridRow();
+        this.uiModelRow = new BaseGridRow();
+        this.uiDefaultResultModelRow = new BaseGridRow();
         this.uiModel.appendRow(uiDefaultResultModelRow);
 
         this.uiModel.appendColumn(uiRowNumberColumn);
@@ -160,11 +163,12 @@ public class AddContextEntryCommandTest {
                                                                                                              any(Optional.class),
                                                                                                              any(HasExpression.class),
                                                                                                              any(Optional.class),
-                                                                                                             any(Optional.class),
+                                                                                                             anyBoolean(),
                                                                                                              anyInt());
         this.uiModelMapper = new ContextUIModelMapper(gridWidget,
                                                       () -> uiModel,
                                                       () -> Optional.of(context),
+                                                      () -> false,
                                                       () -> expressionEditorDefinitions,
                                                       listSelector,
                                                       0);
@@ -332,7 +336,7 @@ public class AddContextEntryCommandTest {
         assertEquals(1,
                      uiModel.getCell(0, 0).getValue().getValue());
         assertEquals(ContextEntryDefaultValueUtilities.PREFIX + "1",
-                     uiModel.getCell(0, 1).getValue().getValue());
+                     ((InformationItemCell.HasNameAndDataTypeCell) uiModel.getCell(0, 1).getValue().getValue()).getName().getValue());
         assertTrue(uiModel.getCell(0, 2).getValue() instanceof ExpressionCellValue);
 
         //Default row
@@ -363,7 +367,7 @@ public class AddContextEntryCommandTest {
         final ContextEntry secondRowEntry = new ContextEntry() {{
             setVariable(new InformationItem());
         }};
-        final DMNGridRow uiSecondModelRow = new DMNGridRow();
+        final GridRow uiSecondModelRow = new BaseGridRow();
         command = spy(new AddContextEntryCommand(context,
                                                  secondRowEntry,
                                                  uiModel,
@@ -401,7 +405,7 @@ public class AddContextEntryCommandTest {
         assertEquals(1,
                      uiModel.getCell(0, 0).getValue().getValue());
         assertEquals(ContextEntryDefaultValueUtilities.PREFIX + "1",
-                     uiModel.getCell(0, 1).getValue().getValue());
+                     ((InformationItemCell.HasNameAndDataTypeCell) uiModel.getCell(0, 1).getValue().getValue()).getName().getValue());
         assertTrue(uiModel.getCell(0, 2).getValue() instanceof ExpressionCellValue);
 
         assertEquals(3,
@@ -409,7 +413,7 @@ public class AddContextEntryCommandTest {
         assertEquals(2,
                      uiModel.getCell(1, 0).getValue().getValue());
         assertEquals(ContextEntryDefaultValueUtilities.PREFIX + "2",
-                     uiModel.getCell(1, 1).getValue().getValue());
+                     ((InformationItemCell.HasNameAndDataTypeCell) uiModel.getCell(1, 1).getValue().getValue()).getName().getValue());
         assertTrue(uiModel.getCell(1, 2).getValue() instanceof ExpressionCellValue);
 
         //Default row
