@@ -25,11 +25,11 @@ import org.kie.workbench.common.dmn.api.definition.v1_1.InformationItem;
 import org.kie.workbench.common.dmn.api.definition.v1_1.List;
 import org.kie.workbench.common.dmn.api.definition.v1_1.LiteralExpression;
 import org.kie.workbench.common.dmn.api.definition.v1_1.Relation;
+import org.kie.workbench.common.dmn.client.editors.expressions.types.dtable.DecisionTableUIModelMapperHelper;
 import org.kie.workbench.common.dmn.client.editors.expressions.types.relation.RelationColumn;
 import org.kie.workbench.common.dmn.client.editors.expressions.types.relation.RelationDefaultValueUtilities;
 import org.kie.workbench.common.dmn.client.editors.expressions.types.relation.RelationUIModelMapper;
 import org.kie.workbench.common.dmn.client.widgets.grid.controls.list.ListSelectorView;
-import org.kie.workbench.common.dmn.client.widgets.grid.model.DMNGridRow;
 import org.kie.workbench.common.stunner.core.client.canvas.AbstractCanvasHandler;
 import org.kie.workbench.common.stunner.core.client.command.CanvasCommandResultBuilder;
 import org.kie.workbench.common.stunner.core.client.command.CanvasViolation;
@@ -42,9 +42,11 @@ import org.mockito.Mock;
 import org.mockito.runners.MockitoJUnitRunner;
 import org.uberfire.ext.wires.core.grids.client.model.GridData;
 import org.uberfire.ext.wires.core.grids.client.model.impl.BaseGridData;
+import org.uberfire.ext.wires.core.grids.client.model.impl.BaseGridRow;
 import org.uberfire.ext.wires.core.grids.client.widget.grid.columns.RowNumberColumn;
 
 import static org.junit.Assert.assertEquals;
+import static org.junit.Assert.assertNull;
 import static org.junit.Assert.assertTrue;
 import static org.mockito.Mockito.doReturn;
 import static org.mockito.Mockito.mock;
@@ -65,7 +67,10 @@ public class AddRelationColumnCommandTest {
     private ListSelectorView.Presenter listSelector;
 
     @Mock
-    private org.uberfire.mvp.Command canvasOperation;
+    private org.uberfire.mvp.Command executeCanvasOperation;
+
+    @Mock
+    private org.uberfire.mvp.Command undoCanvasOperation;
 
     @Mock
     private AbstractCanvasHandler handler;
@@ -107,10 +112,11 @@ public class AddRelationColumnCommandTest {
         command = spy(new AddRelationColumnCommand(relation,
                                                    informationItem,
                                                    uiModel,
-                                                   uiModelColumn,
+                                                   () -> uiModelColumn,
                                                    uiColumnIndex,
                                                    uiModelMapper,
-                                                   canvasOperation));
+                                                   executeCanvasOperation,
+                                                   undoCanvasOperation));
     }
 
     @Test
@@ -296,7 +302,7 @@ public class AddRelationColumnCommandTest {
     @Test
     public void testCanvasCommandExecuteWithRows() {
         relation.getRow().add(new List());
-        uiModel.appendRow(new DMNGridRow());
+        uiModel.appendRow(new BaseGridRow());
         uiModelMapper.fromDMNModel(0, 0);
 
         //Add Graph column first as RelationUIModelMapper relies on the model being first updated
@@ -318,12 +324,11 @@ public class AddRelationColumnCommandTest {
                      uiModel.getRows().get(0).getCells().size());
         assertEquals(1,
                      uiModel.getCell(0, 0).getValue().getValue());
-        assertEquals("",
-                     uiModel.getCell(0, 1).getValue().getValue());
+        assertEquals("", uiModel.getCell(0, 1).getValue().getValue());
 
         verify(command).updateParentInformation();
 
-        verify(canvasOperation).execute();
+        verify(executeCanvasOperation).execute();
     }
 
     @Test
@@ -338,7 +343,7 @@ public class AddRelationColumnCommandTest {
 
         uiModel.appendColumn(mock(RelationColumn.class));
         uiModel.appendColumn(mock(RelationColumn.class));
-        uiModel.appendRow(new DMNGridRow());
+        uiModel.appendRow(new BaseGridRow());
 
         //Add Graph column first as RelationUIModelMapper relies on the model being first updated
         command.newGraphCommand(handler).execute(gce);
@@ -373,13 +378,13 @@ public class AddRelationColumnCommandTest {
 
         verify(command).updateParentInformation();
 
-        verify(canvasOperation).execute();
+        verify(executeCanvasOperation).execute();
     }
 
     @Test
     public void testCanvasCommandUndoWithRows() {
         relation.getRow().add(new List());
-        uiModel.appendRow(new DMNGridRow());
+        uiModel.appendRow(new BaseGridRow());
         uiModelMapper.fromDMNModel(0, 0);
 
         //Add Graph column first as RelationUIModelMapper relies on the model being first updated
@@ -391,7 +396,7 @@ public class AddRelationColumnCommandTest {
         assertEquals(CanvasCommandResultBuilder.SUCCESS,
                      cc.execute(handler));
 
-        reset(command, canvasOperation);
+        reset(command);
         assertEquals(CanvasCommandResultBuilder.SUCCESS,
                      cc.undo(handler));
 
@@ -408,7 +413,7 @@ public class AddRelationColumnCommandTest {
 
         verify(command).updateParentInformation();
 
-        verify(canvasOperation).execute();
+        verify(undoCanvasOperation).execute();
     }
 
     @Test
@@ -422,7 +427,7 @@ public class AddRelationColumnCommandTest {
         assertEquals(CanvasCommandResultBuilder.SUCCESS,
                      cc.execute(handler));
 
-        reset(command, canvasOperation);
+        reset(command);
         assertEquals(CanvasCommandResultBuilder.SUCCESS,
                      cc.undo(handler));
 
@@ -435,6 +440,31 @@ public class AddRelationColumnCommandTest {
 
         verify(command).updateParentInformation();
 
-        verify(canvasOperation).execute();
+        verify(undoCanvasOperation).execute();
+    }
+
+    @Test
+    public void testComponentWidths() {
+        final Command<GraphCommandExecutionContext, RuleViolation> graphCommand = command.newGraphCommand(handler);
+        final Command<AbstractCanvasHandler, CanvasViolation> canvasCommand = command.newCanvasCommand(handler);
+
+        //Execute
+        assertEquals(GraphCommandResultBuilder.SUCCESS,
+                     graphCommand.execute(gce));
+        assertEquals(CanvasCommandResultBuilder.SUCCESS,
+                     canvasCommand.execute(handler));
+
+        assertEquals(relation.getRequiredComponentWidthCount(),
+                     relation.getComponentWidths().size());
+        assertNull(relation.getComponentWidths().get(DecisionTableUIModelMapperHelper.ROW_INDEX_COLUMN_COUNT));
+
+        //Undo
+        assertEquals(GraphCommandResultBuilder.SUCCESS,
+                     graphCommand.undo(gce));
+        assertEquals(CanvasCommandResultBuilder.SUCCESS,
+                     canvasCommand.undo(handler));
+
+        assertEquals(relation.getRequiredComponentWidthCount(),
+                     relation.getComponentWidths().size());
     }
 }
