@@ -88,11 +88,17 @@ public class DecisionNavigatorTreeViewTest {
     @Test
     public void testClean() {
 
-        items.innerHTML = "123";
+        final Element element = mock(Element.class);
+        items.firstChild = element;
+
+        when(items.removeChild(element)).then(a -> {
+            items.firstChild = null;
+            return element;
+        });
 
         treeView.clean();
 
-        assertEquals("", items.innerHTML);
+        verify(items).removeChild(element);
     }
 
     @Test
@@ -155,7 +161,8 @@ public class DecisionNavigatorTreeViewTest {
 
         treeView.update(item, nextItem);
 
-        verify(oldChild).remove();
+        verify(parentElement).removeChild(oldChild);
+        verify(oldChild, never()).remove();
         verify(parentElement).insertBefore(newChild, refChild);
     }
 
@@ -268,12 +275,28 @@ public class DecisionNavigatorTreeViewTest {
 
         final DecisionNavigatorItem item = makeItem("uuid");
         final Element element = mock(Element.class);
+        final Element parentElement = mock(Element.class);
+        element.parentNode = parentElement;
 
         doReturn(element).when(treeView).findItem(item);
 
         treeView.remove(item);
 
-        verify(element).remove();
+        verify(parentElement).removeChild(element);
+        verify(element, never()).remove();
+    }
+
+    @Test
+    public void testRemoveItemWhenDoesNotHaveParent() {
+
+        final DecisionNavigatorItem item = makeItem("uuid");
+        final Element element = mock(Element.class);
+
+        doReturn(element).when(treeView).findItem(item);
+
+        treeView.remove(item);
+
+        verify(element, never()).remove();
     }
 
     @Test
