@@ -19,38 +19,48 @@ package org.kie.workbench.common.dmn.client.editors.expressions.types.relation;
 import java.util.Collections;
 import java.util.Iterator;
 import java.util.Optional;
+import java.util.function.Function;
+import java.util.stream.IntStream;
 
 import com.ait.lienzo.client.core.shape.Viewport;
 import com.ait.lienzo.client.core.types.Transform;
 import com.ait.lienzo.test.LienzoMockitoTestRunner;
 import com.google.gwt.user.client.ui.AbsolutePanel;
-import com.google.gwt.user.client.ui.Widget;
 import org.jboss.errai.ui.client.local.spi.TranslationService;
 import org.junit.Before;
 import org.junit.Test;
 import org.junit.runner.RunWith;
-import org.kie.workbench.common.dmn.api.definition.HasExpression;
 import org.kie.workbench.common.dmn.api.definition.HasName;
+import org.kie.workbench.common.dmn.api.definition.NOPDomainObject;
+import org.kie.workbench.common.dmn.api.definition.v1_1.DMNModelInstrumentedBase;
 import org.kie.workbench.common.dmn.api.definition.v1_1.Decision;
 import org.kie.workbench.common.dmn.api.definition.v1_1.InformationItem;
 import org.kie.workbench.common.dmn.api.definition.v1_1.List;
 import org.kie.workbench.common.dmn.api.definition.v1_1.LiteralExpression;
 import org.kie.workbench.common.dmn.api.definition.v1_1.Relation;
 import org.kie.workbench.common.dmn.api.property.dmn.Name;
+import org.kie.workbench.common.dmn.api.property.dmn.QName;
+import org.kie.workbench.common.dmn.api.property.dmn.types.BuiltInType;
+import org.kie.workbench.common.dmn.client.commands.expressions.types.relation.AddRelationColumnCommand;
 import org.kie.workbench.common.dmn.client.commands.expressions.types.relation.AddRelationRowCommand;
 import org.kie.workbench.common.dmn.client.commands.expressions.types.relation.DeleteRelationColumnCommand;
 import org.kie.workbench.common.dmn.client.commands.expressions.types.relation.DeleteRelationRowCommand;
+import org.kie.workbench.common.dmn.client.commands.factory.DefaultCanvasCommandFactory;
 import org.kie.workbench.common.dmn.client.commands.general.DeleteCellValueCommand;
-import org.kie.workbench.common.dmn.client.commands.general.DeleteHeaderValueCommand;
+import org.kie.workbench.common.dmn.client.commands.general.DeleteHasNameCommand;
 import org.kie.workbench.common.dmn.client.commands.general.SetCellValueCommand;
-import org.kie.workbench.common.dmn.client.commands.general.SetHeaderValueCommand;
+import org.kie.workbench.common.dmn.client.commands.general.SetHasNameCommand;
+import org.kie.workbench.common.dmn.client.commands.general.SetTypeRefCommand;
+import org.kie.workbench.common.dmn.client.editors.expressions.types.GridFactoryCommandUtils;
+import org.kie.workbench.common.dmn.client.editors.types.NameAndDataTypePopoverView;
 import org.kie.workbench.common.dmn.client.resources.i18n.DMNEditorConstants;
-import org.kie.workbench.common.dmn.client.session.DMNEditorSession;
+import org.kie.workbench.common.dmn.client.session.DMNSession;
+import org.kie.workbench.common.dmn.client.widgets.grid.BaseExpressionGrid;
 import org.kie.workbench.common.dmn.client.widgets.grid.columns.factory.TextAreaSingletonDOMElementFactory;
-import org.kie.workbench.common.dmn.client.widgets.grid.columns.factory.TextBoxSingletonDOMElementFactory;
 import org.kie.workbench.common.dmn.client.widgets.grid.controls.container.CellEditorControlsView;
 import org.kie.workbench.common.dmn.client.widgets.grid.controls.list.HasListSelectorControl;
 import org.kie.workbench.common.dmn.client.widgets.grid.controls.list.ListSelectorView;
+import org.kie.workbench.common.dmn.client.widgets.grid.model.DMNGridColumn;
 import org.kie.workbench.common.dmn.client.widgets.grid.model.ExpressionEditorChanged;
 import org.kie.workbench.common.dmn.client.widgets.grid.model.GridCellTuple;
 import org.kie.workbench.common.dmn.client.widgets.grid.model.GridCellValueTuple;
@@ -59,9 +69,15 @@ import org.kie.workbench.common.dmn.client.widgets.panel.DMNGridPanel;
 import org.kie.workbench.common.stunner.core.client.api.SessionManager;
 import org.kie.workbench.common.stunner.core.client.canvas.AbstractCanvasHandler;
 import org.kie.workbench.common.stunner.core.client.canvas.command.AbstractCanvasGraphCommand;
-import org.kie.workbench.common.stunner.core.client.command.CanvasCommandFactory;
+import org.kie.workbench.common.stunner.core.client.canvas.event.selection.DomainObjectSelectionEvent;
 import org.kie.workbench.common.stunner.core.client.command.SessionCommandManager;
+import org.kie.workbench.common.stunner.core.command.impl.CompositeCommand;
+import org.kie.workbench.common.stunner.core.diagram.Diagram;
+import org.kie.workbench.common.stunner.core.graph.Graph;
+import org.kie.workbench.common.stunner.core.graph.Node;
+import org.kie.workbench.common.stunner.core.graph.command.GraphCommandExecutionContext;
 import org.kie.workbench.common.stunner.core.util.DefinitionUtils;
+import org.kie.workbench.common.stunner.forms.client.event.RefreshFormPropertiesEvent;
 import org.mockito.ArgumentCaptor;
 import org.mockito.Captor;
 import org.mockito.Mock;
@@ -79,38 +95,44 @@ import org.uberfire.mvp.Command;
 
 import static org.assertj.core.api.Assertions.assertThat;
 import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.assertFalse;
 import static org.junit.Assert.assertTrue;
 import static org.mockito.Matchers.any;
+import static org.mockito.Matchers.anyInt;
 import static org.mockito.Matchers.anyString;
 import static org.mockito.Matchers.eq;
 import static org.mockito.Mockito.doAnswer;
-import static org.mockito.Mockito.doReturn;
 import static org.mockito.Mockito.mock;
+import static org.mockito.Mockito.never;
+import static org.mockito.Mockito.reset;
 import static org.mockito.Mockito.spy;
-import static org.mockito.Mockito.times;
 import static org.mockito.Mockito.verify;
 import static org.mockito.Mockito.when;
 
 @RunWith(LienzoMockitoTestRunner.class)
 public class RelationGridTest {
 
-    private final static int INSERT_COLUMN_BEFORE = 0;
+    private final static int HEADER_COLUMNS = 0;
 
-    private final static int INSERT_COLUMN_AFTER = 1;
+    private final static int INSERT_COLUMN_BEFORE = 1;
 
-    private final static int DELETE_COLUMN = 2;
+    private final static int INSERT_COLUMN_AFTER = 2;
 
-    private final static int DIVIDER = 3;
+    private final static int DELETE_COLUMN = 3;
 
-    private final static int INSERT_ROW_ABOVE = 4;
+    private final static int HEADER_ROWS = 4;
 
-    private final static int INSERT_ROW_BELOW = 5;
+    private final static int INSERT_ROW_ABOVE = 5;
 
-    private final static int DELETE_ROW = 6;
+    private final static int INSERT_ROW_BELOW = 6;
+
+    private final static int DELETE_ROW = 7;
 
     private static final String NODE_UUID = "uuid";
 
+    private static final String NAME = "column-1";
+
+    private static final String NAME_NEW = "name-new";
+
     private GridCellTuple tupleWithoutValue;
 
     private GridCellValueTuple tupleWithValue;
@@ -124,9 +146,6 @@ public class RelationGridTest {
     @Mock
     private GridColumn parentGridColumn;
 
-    @Mock
-    private HasExpression hasExpression;
-
     @Mock
     private Viewport viewport;
 
@@ -152,16 +171,28 @@ public class RelationGridTest {
     private SessionManager sessionManager;
 
     @Mock
-    private DMNEditorSession dmnEditorSession;
+    private DMNSession session;
 
     @Mock
     private AbstractCanvasHandler canvasHandler;
 
+    @Mock
+    private GraphCommandExecutionContext graphContext;
+
+    @Mock
+    private Diagram diagram;
+
+    @Mock
+    private Graph graph;
+
+    @Mock
+    private Node node;
+
     @Mock
     private SessionCommandManager<AbstractCanvasHandler> sessionCommandManager;
 
     @Mock
-    private CanvasCommandFactory<AbstractCanvasHandler> canvasCommandFactory;
+    private DefaultCanvasCommandFactory canvasCommandFactory;
 
     @Mock
     private CellEditorControlsView.Presenter cellEditorControls;
@@ -175,6 +206,18 @@ public class RelationGridTest {
     @Mock
     private EventSourceMock<ExpressionEditorChanged> editorSelectedEvent;
 
+    @Mock
+    private EventSourceMock<RefreshFormPropertiesEvent> refreshFormPropertiesEvent;
+
+    @Mock
+    private EventSourceMock<DomainObjectSelectionEvent> domainObjectSelectionEvent;
+
+    @Mock
+    private NameAndDataTypePopoverView.Presenter headerEditor;
+
+    @Captor
+    private ArgumentCaptor<AddRelationColumnCommand> addColumnCommand;
+
     @Captor
     private ArgumentCaptor<DeleteRelationColumnCommand> deleteColumnCommand;
 
@@ -187,10 +230,18 @@ public class RelationGridTest {
     @Captor
     private ArgumentCaptor<GridLayerRedrawManager.PrioritizedCommand> redrawCommandCaptor;
 
+    @Captor
+    private ArgumentCaptor<CompositeCommand> compositeCommandCaptor;
+
+    @Captor
+    private ArgumentCaptor<DomainObjectSelectionEvent> domainObjectSelectionEventCaptor;
+
     private GridCellTuple parent;
 
     private Relation relation = new Relation();
 
+    private Decision hasExpression = new Decision();
+
     private Optional<Relation> expression = Optional.of(relation);
 
     private Optional<HasName> hasName = Optional.empty();
@@ -201,55 +252,66 @@ public class RelationGridTest {
 
     @Before
     @SuppressWarnings("unchecked")
-    public void setUp() throws Exception {
+    public void setUp() {
+        when(sessionManager.getCurrentSession()).thenReturn(session);
+        when(session.getGridPanel()).thenReturn(gridPanel);
+        when(session.getGridLayer()).thenReturn(gridLayer);
+        when(session.getCellEditorControls()).thenReturn(cellEditorControls);
+
         tupleWithoutValue = new GridCellTuple(0, 1, gridWidget);
         tupleWithValue = new GridCellValueTuple<>(0, 1, gridWidget, new BaseGridCellValue<>("value"));
 
-        definition = new RelationEditorDefinition(gridPanel,
-                                                  gridLayer,
-                                                  definitionUtils,
+        definition = new RelationEditorDefinition(definitionUtils,
                                                   sessionManager,
                                                   sessionCommandManager,
                                                   canvasCommandFactory,
                                                   editorSelectedEvent,
-                                                  cellEditorControls,
+                                                  refreshFormPropertiesEvent,
+                                                  domainObjectSelectionEvent,
                                                   listSelector,
-                                                  translationService);
+                                                  translationService,
+                                                  headerEditor);
 
         final Decision decision = new Decision();
         decision.setName(new Name("name"));
         hasName = Optional.of(decision);
         expression = definition.getModelClass();
-        definition.enrich(Optional.empty(), expression);
+        definition.enrich(Optional.empty(), hasExpression, expression);
 
-        doReturn(canvasHandler).when(dmnEditorSession).getCanvasHandler();
-        doReturn(dmnEditorSession).when(sessionManager).getCurrentSession();
-        doReturn(parentGridData).when(parentGridWidget).getModel();
-        doReturn(Collections.singletonList(parentGridColumn)).when(parentGridData).getColumns();
+        when(session.getCanvasHandler()).thenReturn(canvasHandler);
+        when(parentGridWidget.getModel()).thenReturn(parentGridData);
+        when(parentGridData.getColumns()).thenReturn(Collections.singletonList(parentGridColumn));
 
         parent = spy(new GridCellTuple(0, 0, parentGridWidget));
 
+        when(canvasHandler.getDiagram()).thenReturn(diagram);
+        when(canvasHandler.getGraphExecutionContext()).thenReturn(graphContext);
+        when(diagram.getGraph()).thenReturn(graph);
+        when(graph.nodes()).thenReturn(Collections.singletonList(node));
+
         when(gridWidget.getModel()).thenReturn(new BaseGridData(false));
         when(gridLayer.getDomElementContainer()).thenReturn(gridLayerDomElementContainer);
         when(gridLayerDomElementContainer.iterator()).thenReturn(mock(Iterator.class));
-        when(gridLayer.getVisibleBounds()).thenReturn(new BaseBounds(0, 0, 100, 200));
+        when(gridLayer.getVisibleBounds()).thenReturn(new BaseBounds(0, 0, 200, 200));
         when(gridLayer.getViewport()).thenReturn(viewport);
         when(viewport.getTransform()).thenReturn(transform);
 
         doAnswer((i) -> i.getArguments()[0].toString()).when(translationService).format(anyString());
+        doAnswer((i) -> i.getArguments()[0].toString()).when(translationService).getTranslation(anyString());
     }
 
     private void setupGrid(final int nesting) {
+        this.hasExpression.setExpression(expression.get());
         this.grid = spy((RelationGrid) definition.getEditor(parent,
                                                             nesting == 0 ? Optional.of(NODE_UUID) : Optional.empty(),
                                                             hasExpression,
-                                                            expression,
                                                             hasName,
+                                                            false,
                                                             nesting).get());
     }
 
     @Test
-    public void testInitialiseUiColumnsEmptyModel() throws Exception {
+    public void testInitialiseUiColumnsEmptyModel() {
         expression = Optional.of(new Relation());
 
         setupGrid(0);
@@ -262,7 +324,7 @@ public class RelationGridTest {
     }
 
     @Test
-    public void testInitialiseUiColumns() throws Exception {
+    public void testInitialiseUiColumns() {
         final String columnHeader = "first column";
         relation.getColumn().add(new InformationItem() {{
             getName().setValue(columnHeader);
@@ -280,7 +342,7 @@ public class RelationGridTest {
     }
 
     @Test
-    public void testInitialiseUiModel() throws Exception {
+    public void testInitialiseUiModel() {
         relation.getColumn().add(new InformationItem() {{
             getName().setValue("first column header");
         }});
@@ -288,12 +350,12 @@ public class RelationGridTest {
         final String secondRowValue = "first column value 2";
         relation.getRow().add(new List() {{
             getExpression().add(new LiteralExpression() {{
-                setText(firstRowValue);
+                getText().setValue(firstRowValue);
             }});
         }});
         relation.getRow().add(new List() {{
             getExpression().add(new LiteralExpression() {{
-                setText(secondRowValue);
+                getText().setValue(secondRowValue);
             }});
         }});
 
@@ -327,17 +389,28 @@ public class RelationGridTest {
     }
 
     @Test
-    public void testHeaderVisibilityWhenNested() {
-        setupGrid(1);
+    public void testInitialColumnWidthsFromDefinition() {
+        setupGrid(0);
 
-        assertFalse(grid.isHeaderHidden());
+        assertComponentWidths(50.0,
+                              DMNGridColumn.DEFAULT_WIDTH);
     }
 
     @Test
-    public void testHeaderVisibilityWhenNotNested() {
+    public void testInitialColumnWidthsFromExpression() {
+        final java.util.List<Double> componentWidths = expression.get().getComponentWidths();
+        componentWidths.set(0, 200.0);
+        componentWidths.set(1, 300.0);
+
         setupGrid(0);
 
-        assertFalse(grid.isHeaderHidden());
+        assertComponentWidths(200.0,
+                              300.0);
+    }
+
+    private void assertComponentWidths(final double... widths) {
+        final GridData uiModel = grid.getModel();
+        IntStream.range(0, widths.length).forEach(i -> assertEquals(widths[i], uiModel.getColumns().get(i).getWidth(), 0.0));
     }
 
     @Test
@@ -353,24 +426,51 @@ public class RelationGridTest {
 
         final java.util.List<HasListSelectorControl.ListSelectorItem> items = grid.getItems(0, 0);
 
-        assertThat(items.size()).isEqualTo(7);
-        assertListSelectorItem(items.get(INSERT_COLUMN_BEFORE),
-                               DMNEditorConstants.RelationEditor_InsertColumnBefore);
-        assertListSelectorItem(items.get(INSERT_COLUMN_AFTER),
-                               DMNEditorConstants.RelationEditor_InsertColumnAfter);
-        assertListSelectorItem(items.get(DELETE_COLUMN),
-                               DMNEditorConstants.RelationEditor_DeleteColumn);
-        assertThat(items.get(DIVIDER)).isInstanceOf(HasListSelectorControl.ListSelectorDividerItem.class);
-        assertListSelectorItem(items.get(INSERT_ROW_ABOVE),
-                               DMNEditorConstants.RelationEditor_InsertRowAbove);
-        assertListSelectorItem(items.get(INSERT_ROW_BELOW),
-                               DMNEditorConstants.RelationEditor_InsertRowBelow);
-        assertListSelectorItem(items.get(DELETE_ROW),
-                               DMNEditorConstants.RelationEditor_DeleteRow);
+        assertThat(items.size()).isEqualTo(8);
+        assertListSelectorHeaderItem(items.get(HEADER_COLUMNS),
+                                     DMNEditorConstants.RelationEditor_HeaderColumns);
+        assertListSelectorTextItem(items.get(INSERT_COLUMN_BEFORE),
+                                   DMNEditorConstants.RelationEditor_InsertColumnLeft);
+        assertListSelectorTextItem(items.get(INSERT_COLUMN_AFTER),
+                                   DMNEditorConstants.RelationEditor_InsertColumnRight);
+        assertListSelectorTextItem(items.get(DELETE_COLUMN),
+                                   DMNEditorConstants.RelationEditor_DeleteColumn);
+        assertListSelectorHeaderItem(items.get(HEADER_ROWS),
+                                     DMNEditorConstants.RelationEditor_HeaderRows);
+        assertListSelectorTextItem(items.get(INSERT_ROW_ABOVE),
+                                   DMNEditorConstants.RelationEditor_InsertRowAbove);
+        assertListSelectorTextItem(items.get(INSERT_ROW_BELOW),
+                                   DMNEditorConstants.RelationEditor_InsertRowBelow);
+        assertListSelectorTextItem(items.get(DELETE_ROW),
+                                   DMNEditorConstants.RelationEditor_DeleteRow);
     }
 
-    private void assertListSelectorItem(final HasListSelectorControl.ListSelectorItem item,
-                                        final String text) {
+    @Test
+    public void testGetHeaderItems() {
+        setupGrid(0);
+
+        final java.util.List<HasListSelectorControl.ListSelectorItem> items = grid.getHeaderItems(0, 0);
+
+        assertThat(items.size()).isEqualTo(4);
+        assertListSelectorHeaderItem(items.get(HEADER_COLUMNS),
+                                     DMNEditorConstants.RelationEditor_HeaderColumns);
+        assertListSelectorTextItem(items.get(INSERT_COLUMN_BEFORE),
+                                   DMNEditorConstants.RelationEditor_InsertColumnLeft);
+        assertListSelectorTextItem(items.get(INSERT_COLUMN_AFTER),
+                                   DMNEditorConstants.RelationEditor_InsertColumnRight);
+        assertListSelectorTextItem(items.get(DELETE_COLUMN),
+                                   DMNEditorConstants.RelationEditor_DeleteColumn);
+    }
+
+    private void assertListSelectorHeaderItem(final HasListSelectorControl.ListSelectorItem item,
+                                              final String text) {
+        assertThat(item).isInstanceOf(HasListSelectorControl.ListSelectorHeaderItem.class);
+        final HasListSelectorControl.ListSelectorHeaderItem hi = (HasListSelectorControl.ListSelectorHeaderItem) item;
+        assertThat(hi.getText()).isEqualTo(text);
+    }
+
+    private void assertListSelectorTextItem(final HasListSelectorControl.ListSelectorItem item,
+                                            final String text) {
         assertThat(item).isInstanceOf(HasListSelectorControl.ListSelectorTextItem.class);
         final HasListSelectorControl.ListSelectorTextItem ti = (HasListSelectorControl.ListSelectorTextItem) item;
         assertThat(ti.getText()).isEqualTo(text);
@@ -394,13 +494,13 @@ public class RelationGridTest {
         setupGrid(0);
         mockInsertColumnCommandExecution();
 
-        final java.util.List<HasListSelectorControl.ListSelectorItem> items = grid.getItems(0, 0);
+        final java.util.List<HasListSelectorControl.ListSelectorItem> items = grid.getItems(0, 1);
         final HasListSelectorControl.ListSelectorTextItem ti = (HasListSelectorControl.ListSelectorTextItem) items.get(INSERT_COLUMN_BEFORE);
 
         grid.onItemSelected(ti);
 
         verify(cellEditorControls).hide();
-        verify(grid).addColumn(eq(0));
+        verify(grid).addColumn(eq(1));
     }
 
     @Test
@@ -408,13 +508,13 @@ public class RelationGridTest {
         setupGrid(0);
         mockInsertColumnCommandExecution();
 
-        final java.util.List<HasListSelectorControl.ListSelectorItem> items = grid.getItems(0, 0);
+        final java.util.List<HasListSelectorControl.ListSelectorItem> items = grid.getItems(0, 1);
         final HasListSelectorControl.ListSelectorTextItem ti = (HasListSelectorControl.ListSelectorTextItem) items.get(INSERT_COLUMN_AFTER);
 
         grid.onItemSelected(ti);
 
         verify(cellEditorControls).hide();
-        verify(grid).addColumn(eq(1));
+        verify(grid).addColumn(eq(2));
     }
 
     @Test
@@ -522,6 +622,49 @@ public class RelationGridTest {
         assertListSelectorItemEnabled(1, 0, DELETE_ROW, true);
     }
 
+    @Test
+    public void testOnHeaderItemSelectedInsertColumnBefore() {
+        setupGrid(0);
+        mockInsertColumnCommandExecution();
+
+        final java.util.List<HasListSelectorControl.ListSelectorItem> items = grid.getHeaderItems(0, RelationUIModelMapperHelper.ROW_INDEX_COLUMN_COUNT);
+        final HasListSelectorControl.ListSelectorTextItem ti = (HasListSelectorControl.ListSelectorTextItem) items.get(INSERT_COLUMN_BEFORE);
+
+        grid.onItemSelected(ti);
+
+        verify(cellEditorControls).hide();
+        verify(grid).addColumn(eq(1));
+    }
+
+    @Test
+    public void testOnHeaderItemSelectedInsertColumnAfter() {
+        setupGrid(0);
+        mockInsertColumnCommandExecution();
+
+        final java.util.List<HasListSelectorControl.ListSelectorItem> items = grid.getHeaderItems(0, RelationUIModelMapperHelper.ROW_INDEX_COLUMN_COUNT);
+        final HasListSelectorControl.ListSelectorTextItem ti = (HasListSelectorControl.ListSelectorTextItem) items.get(INSERT_COLUMN_AFTER);
+
+        grid.onItemSelected(ti);
+
+        verify(cellEditorControls).hide();
+        verify(grid).addColumn(eq(2));
+    }
+
+    @Test
+    public void testOnHeaderItemSelectedDeleteColumn() {
+        relation.getColumn().add(new InformationItem());
+        setupGrid(0);
+
+        //Cannot delete column 0 since it is the RowNumber column. The first Relation column is 1.
+        final java.util.List<HasListSelectorControl.ListSelectorItem> items = grid.getHeaderItems(0, RelationUIModelMapperHelper.ROW_INDEX_COLUMN_COUNT);
+        final HasListSelectorControl.ListSelectorTextItem ti = (HasListSelectorControl.ListSelectorTextItem) items.get(DELETE_COLUMN);
+
+        grid.onItemSelected(ti);
+
+        verify(cellEditorControls).hide();
+        verify(grid).deleteColumn(eq(1));
+    }
+
     @Test
     public void testGetItemsWithCellSelectionsCoveringMultipleRows() {
         setupGrid(0);
@@ -539,7 +682,7 @@ public class RelationGridTest {
     public void testGetItemsWithCellSelectionsCoveringMultipleColumns() {
         setupGrid(0);
 
-        addColumn(0);
+        addColumn(1);
         grid.getModel().selectCell(0, 0);
         grid.getModel().selectCell(0, 1);
 
@@ -561,27 +704,28 @@ public class RelationGridTest {
     public void testAddColumn() throws Exception {
         setupGrid(0);
 
-        addColumn(0);
+        addColumn(1);
 
-        verify(parent).proposeContainingColumnWidth(grid.getWidth() + grid.getPadding() * 2);
-        verify(parentGridColumn).setWidth(grid.getWidth() + grid.getPadding() * 2);
-        verify(gridLayer, times(2)).batch(redrawCommandCaptor.capture());
-        verify(gridPanel).refreshScrollPosition();
-        verify(gridPanel).updatePanelSize();
+        verifyCommandExecuteOperation(BaseExpressionGrid.RESIZE_EXISTING);
+        verify(grid).selectHeaderCell(eq(0),
+                                      eq(1),
+                                      eq(false),
+                                      eq(false));
 
-        final java.util.List<GridLayerRedrawManager.PrioritizedCommand> redrawCommands = redrawCommandCaptor.getAllValues();
+        verify(headerEditor).bind(any(RelationColumnHeaderMetaData.class),
+                                  eq(0),
+                                  eq(1));
+        verify(cellEditorControls).show(eq(headerEditor),
+                                        eq(Optional.of(DMNEditorConstants.RelationEditor_EditRelation)),
+                                        anyInt(),
+                                        anyInt());
 
-        //First call redraws grid following addition of new row
-        final GridLayerRedrawManager.PrioritizedCommand redrawCommand0 = redrawCommands.get(0);
-        redrawCommand0.execute();
+        //Check undo operation
+        reset(gridPanel, gridLayer, grid, parentGridColumn);
+        verify(sessionCommandManager).execute(eq(canvasHandler), addColumnCommand.capture());
+        addColumnCommand.getValue().undo(canvasHandler);
 
-        verify(gridLayer).draw();
-
-        //Second call displays the inline editor for the new row
-        final GridLayerRedrawManager.PrioritizedCommand redrawCommand1 = redrawCommands.get(1);
-        redrawCommand1.execute();
-
-        verify(gridLayerDomElementContainer).add(any(Widget.class));
+        verifyCommandUndoOperation(BaseExpressionGrid.RESIZE_EXISTING_MINIMUM);
     }
 
     private void addColumn(final int index) {
@@ -599,8 +743,32 @@ public class RelationGridTest {
         });
     }
 
+    private void verifyCommandExecuteOperation(final Function<BaseExpressionGrid, Double> resizeFunction) {
+        verify(parent).proposeContainingColumnWidth(eq(grid.getWidth() + grid.getPadding() * 2), eq(resizeFunction));
+        verify(parentGridColumn).setWidth(grid.getWidth() + grid.getPadding() * 2);
+        verify(gridLayer).batch(redrawCommandCaptor.capture());
+        verify(gridPanel).refreshScrollPosition();
+        verify(gridPanel).updatePanelSize();
+
+        final GridLayerRedrawManager.PrioritizedCommand redrawCommand = redrawCommandCaptor.getValue();
+        redrawCommand.execute();
+        verify(gridLayer).draw();
+    }
+
+    private void verifyCommandUndoOperation(final Function<BaseExpressionGrid, Double> resizeFunction) {
+        verify(parent).proposeContainingColumnWidth(eq(grid.getWidth() + grid.getPadding() * 2), eq(resizeFunction));
+        verify(parentGridColumn).setWidth(grid.getWidth() + grid.getPadding() * 2);
+        verify(gridLayer).batch(redrawCommandCaptor.capture());
+        verify(gridPanel).refreshScrollPosition();
+        verify(gridPanel).updatePanelSize();
+
+        assertThat(redrawCommandCaptor.getAllValues()).hasSize(2);
+        redrawCommandCaptor.getAllValues().get(1).execute();
+        verify(gridLayer).draw();
+    }
+
     @Test
-    public void testDeleteColumn() throws Exception {
+    public void testDeleteColumn() {
         relation.getColumn().add(new InformationItem());
         setupGrid(0);
 
@@ -608,24 +776,25 @@ public class RelationGridTest {
         grid.deleteColumn(RelationUIModelMapperHelper.ROW_INDEX_COLUMN_COUNT);
 
         verify(sessionCommandManager).execute(eq(canvasHandler), deleteColumnCommand.capture());
-
         deleteColumnCommand.getValue().execute(canvasHandler);
-        verify(parent).proposeContainingColumnWidth(grid.getWidth() + grid.getPadding() * 2);
-        verify(parentGridColumn).setWidth(grid.getWidth() + grid.getPadding() * 2);
-        verify(gridLayer).batch(any(GridLayerRedrawManager.PrioritizedCommand.class));
-        verify(gridPanel).refreshScrollPosition();
-        verify(gridPanel).updatePanelSize();
+
+        verifyCommandExecuteOperation(BaseExpressionGrid.RESIZE_EXISTING_MINIMUM);
+
+        //Check undo operation
+        reset(gridPanel, gridLayer, grid, parentGridColumn);
+        verify(sessionCommandManager).execute(eq(canvasHandler), deleteColumnCommand.capture());
+        deleteColumnCommand.getValue().undo(canvasHandler);
+
+        verifyCommandUndoOperation(BaseExpressionGrid.RESIZE_EXISTING);
     }
 
     @Test
-    public void testAddRow() throws Exception {
+    public void testAddRow() {
         setupGrid(0);
 
         addRow(0);
 
-        verify(gridLayer).batch(any(GridLayerRedrawManager.PrioritizedCommand.class));
-        verify(gridPanel).refreshScrollPosition();
-        verify(gridPanel).updatePanelSize();
+        verifyCommandExecuteOperation(BaseExpressionGrid.RESIZE_EXISTING);
     }
 
     private void addRow(final int index) {
@@ -637,7 +806,7 @@ public class RelationGridTest {
     }
 
     @Test
-    public void testDeleteRow() throws Exception {
+    public void testDeleteRow() {
         relation.getRow().add(new List());
         setupGrid(0);
 
@@ -646,9 +815,8 @@ public class RelationGridTest {
         verify(sessionCommandManager).execute(eq(canvasHandler), deleteRowCommand.capture());
 
         deleteRowCommand.getValue().execute(canvasHandler);
-        verify(gridLayer).batch(any(GridLayerRedrawManager.PrioritizedCommand.class));
-        verify(gridPanel).refreshScrollPosition();
-        verify(gridPanel).updatePanelSize();
+
+        verifyCommandExecuteOperation(BaseExpressionGrid.RESIZE_EXISTING);
     }
 
     @Test
@@ -670,20 +838,200 @@ public class RelationGridTest {
     }
 
     @Test
-    public void testHeaderFactoryWhenNested() {
-        setupGrid(1);
+    public void testGetDisplayName() {
+        setupGrid(0);
 
-        final TextBoxSingletonDOMElementFactory factory = grid.getHeaderTextBoxFactory();
-        assertThat(factory.getHasNoValueCommand().apply(tupleWithoutValue)).isInstanceOf(DeleteHeaderValueCommand.class);
-        assertThat(factory.getHasValueCommand().apply(tupleWithValue)).isInstanceOf(SetHeaderValueCommand.class);
+        assertThat(extractHeaderMetaData().getName().getValue()).isEqualTo(NAME);
+    }
+
+    private RelationColumnHeaderMetaData extractHeaderMetaData() {
+        final RelationColumn column = (RelationColumn) grid.getModel().getColumns().get(1);
+        return (RelationColumnHeaderMetaData) column.getHeaderMetaData().get(0);
     }
 
     @Test
-    public void testHeaderFactoryWhenNotNested() {
+    @SuppressWarnings("unchecked")
+    public void testSetDisplayNameWithNoChange() {
         setupGrid(0);
 
-        final TextBoxSingletonDOMElementFactory factory = grid.getHeaderTextBoxFactory();
-        assertThat(factory.getHasNoValueCommand().apply(tupleWithoutValue)).isInstanceOf(DeleteHeaderValueCommand.class);
-        assertThat(factory.getHasValueCommand().apply(tupleWithValue)).isInstanceOf(SetHeaderValueCommand.class);
+        extractHeaderMetaData().setName(new Name(NAME));
+
+        verify(sessionCommandManager, never()).execute(any(AbstractCanvasHandler.class),
+                                                       any(org.kie.workbench.common.stunner.core.command.Command.class));
+    }
+
+    @Test
+    @SuppressWarnings("unchecked")
+    public void testSetDisplayNameWithEmptyValue() {
+        setupGrid(0);
+
+        extractHeaderMetaData().setName(new Name());
+
+        verify(sessionCommandManager).execute(eq(canvasHandler),
+                                              compositeCommandCaptor.capture());
+
+        GridFactoryCommandUtils.assertCommands(compositeCommandCaptor.getValue(),
+                                               DeleteHasNameCommand.class);
+    }
+
+    @Test
+    @SuppressWarnings("unchecked")
+    public void testSetDisplayNameWithNullValue() {
+        setupGrid(0);
+
+        extractHeaderMetaData().setName(null);
+
+        verify(sessionCommandManager).execute(eq(canvasHandler),
+                                              compositeCommandCaptor.capture());
+
+        GridFactoryCommandUtils.assertCommands(compositeCommandCaptor.getValue(),
+                                               DeleteHasNameCommand.class);
+    }
+
+    @Test
+    @SuppressWarnings("unchecked")
+    public void testSetDisplayNameWithNonEmptyValue() {
+        setupGrid(0);
+
+        extractHeaderMetaData().setName(new Name(NAME_NEW));
+
+        verify(sessionCommandManager).execute(eq(canvasHandler),
+                                              compositeCommandCaptor.capture());
+
+        GridFactoryCommandUtils.assertCommands(compositeCommandCaptor.getValue(),
+                                               SetHasNameCommand.class);
+    }
+
+    @Test
+    public void testGetTypeRef() {
+        setupGrid(0);
+
+        assertThat(extractHeaderMetaData().getTypeRef()).isNotNull();
+    }
+
+    @Test
+    public void testSetTypeRef() {
+        setupGrid(0);
+
+        extractHeaderMetaData().setTypeRef(new QName(QName.NULL_NS_URI,
+                                                     BuiltInType.DATE.getName()));
+
+        verify(sessionCommandManager).execute(eq(canvasHandler),
+                                              any(SetTypeRefCommand.class));
+    }
+
+    @Test
+    public void testSetTypeRefWithoutChange() {
+        setupGrid(0);
+
+        extractHeaderMetaData().setTypeRef(new QName());
+
+        verify(sessionCommandManager, never()).execute(any(AbstractCanvasHandler.class),
+                                                       any(SetTypeRefCommand.class));
+    }
+
+    @Test
+    public void testSelectRow() {
+        setupGrid(0);
+
+        grid.selectCell(0, 0, false, false);
+
+        verify(domainObjectSelectionEvent).fire(domainObjectSelectionEventCaptor.capture());
+
+        final DomainObjectSelectionEvent domainObjectSelectionEvent = domainObjectSelectionEventCaptor.getValue();
+        assertThat(domainObjectSelectionEvent.getDomainObject()).isInstanceOf(NOPDomainObject.class);
+    }
+
+    @Test
+    @SuppressWarnings("unchecked")
+    public void testSelectMultipleCells() {
+        setupGrid(0);
+        addRow(0);
+        addColumn(1);
+
+        //DomainObject selected when row added, so reset for this test
+        reset(domainObjectSelectionEvent);
+
+        grid.selectCell(0, 1, false, false);
+
+        verify(domainObjectSelectionEvent).fire(domainObjectSelectionEventCaptor.capture());
+
+        final DomainObjectSelectionEvent event1 = domainObjectSelectionEventCaptor.getValue();
+        assertThat(event1.getDomainObject()).isEqualTo(expression.get().getRow().get(0).getExpression().get(0));
+
+        //Reset DomainObjectSelectionEvent tested above.
+        reset(domainObjectSelectionEvent);
+
+        grid.selectCell(0, 2, false, true);
+
+        verify(domainObjectSelectionEvent).fire(domainObjectSelectionEventCaptor.capture());
+
+        final DomainObjectSelectionEvent event2 = domainObjectSelectionEventCaptor.getValue();
+        assertThat(event2.getDomainObject()).isInstanceOf(NOPDomainObject.class);
+    }
+
+    @Test
+    @SuppressWarnings("unchecked")
+    public void testSelectSingleCellWithHeaderSelected() {
+        setupGrid(0);
+
+        grid.selectHeaderCell(0, RelationUIModelMapperHelper.ROW_INDEX_COLUMN_COUNT, false, false);
+
+        verify(domainObjectSelectionEvent).fire(domainObjectSelectionEventCaptor.capture());
+
+        final DomainObjectSelectionEvent event1 = domainObjectSelectionEventCaptor.getValue();
+        assertThat(event1.getDomainObject()).isEqualTo(expression.get().getColumn().get(0));
+
+        //Reset DomainObjectSelectionEvent tested above.
+        reset(domainObjectSelectionEvent);
+
+        grid.selectCell(0, RelationUIModelMapperHelper.ROW_INDEX_COLUMN_COUNT, false, true);
+
+        verify(domainObjectSelectionEvent).fire(domainObjectSelectionEventCaptor.capture());
+
+        final DomainObjectSelectionEvent event2 = domainObjectSelectionEventCaptor.getValue();
+        assertThat(event2.getDomainObject()).isEqualTo(expression.get().getRow().get(0).getExpression().get(0));
+    }
+
+    @Test
+    public void testSelectExpression() {
+        setupGrid(0);
+
+        grid.selectCell(0, 1, false, false);
+
+        verify(domainObjectSelectionEvent).fire(domainObjectSelectionEventCaptor.capture());
+
+        final DomainObjectSelectionEvent domainObjectSelectionEvent = domainObjectSelectionEventCaptor.getValue();
+        assertThat(domainObjectSelectionEvent.getDomainObject()).isEqualTo(expression.get().getRow().get(0).getExpression().get(0));
+    }
+
+    @Test
+    public void testSelectHeaderExpression() {
+        setupGrid(0);
+
+        grid.selectHeaderCell(0, RelationUIModelMapperHelper.ROW_INDEX_COLUMN_COUNT, false, false);
+
+        verify(domainObjectSelectionEvent).fire(domainObjectSelectionEventCaptor.capture());
+
+        final DomainObjectSelectionEvent domainObjectSelectionEvent = domainObjectSelectionEventCaptor.getValue();
+        assertThat(domainObjectSelectionEvent.getDomainObject()).isEqualTo(expression.get().getColumn().get(0));
+    }
+
+    @Test
+    public void testAsDMNModelInstrumentedBase() {
+        setupGrid(0);
+
+        final DMNModelInstrumentedBase actual = extractHeaderMetaData().asDMNModelInstrumentedBase();
+
+        assertThat(actual).isInstanceOf(InformationItem.class);
+    }
+
+    @Test
+    public void testSelectFirstCell() {
+        setupGrid(0);
+
+        grid.selectFirstCell();
+
+        assertThat(grid.getModel().getSelectedCells()).containsOnly(new GridData.SelectedCell(0, 1));
     }
 }
