@@ -21,6 +21,7 @@ import java.util.Arrays;
 import java.util.List;
 import java.util.Optional;
 
+import com.ait.lienzo.test.LienzoMockitoTestRunner;
 import org.jboss.errai.ioc.client.api.ManagedInstance;
 import org.jboss.errai.ui.client.local.spi.TranslationService;
 import org.junit.Before;
@@ -44,10 +45,6 @@ import org.kie.workbench.common.dmn.client.editors.types.persistence.validation.
 import org.mockito.InOrder;
 import org.mockito.Mock;
 import org.mockito.Mockito;
-import org.powermock.api.mockito.PowerMockito;
-import org.powermock.core.classloader.annotations.PrepareForTest;
-import org.powermock.modules.junit4.PowerMockRunner;
-import org.uberfire.commons.uuid.UUID;
 import org.uberfire.mocks.EventSourceMock;
 
 import static java.util.Arrays.asList;
@@ -61,6 +58,7 @@ import static org.junit.Assert.assertTrue;
 import static org.kie.workbench.common.dmn.client.resources.i18n.DMNEditorConstants.DataTypeManager_None;
 import static org.kie.workbench.common.dmn.client.resources.i18n.DMNEditorConstants.DataTypeManager_Structure;
 import static org.mockito.Matchers.any;
+import static org.mockito.Matchers.anyBoolean;
 import static org.mockito.Matchers.anyString;
 import static org.mockito.Matchers.eq;
 import static org.mockito.Mockito.doReturn;
@@ -68,10 +66,8 @@ import static org.mockito.Mockito.mock;
 import static org.mockito.Mockito.spy;
 import static org.mockito.Mockito.verify;
 import static org.mockito.Mockito.when;
-import static org.powermock.api.mockito.PowerMockito.mockStatic;
 
-@PrepareForTest({UUID.class})
-@RunWith(PowerMockRunner.class)
+@RunWith(LienzoMockitoTestRunner.class)
 public class DataTypeManagerTest {
 
     @Mock
@@ -113,8 +109,6 @@ public class DataTypeManagerTest {
 
     @Before
     public void setup() {
-        mockStatic(UUID.class);
-        PowerMockito.when(UUID.uuid()).thenReturn("uuid");
 
         when(translationService.format(DataTypeManager_None)).thenReturn("--");
         when(translationService.format(DataTypeManager_Structure)).thenReturn("Structure");
@@ -226,7 +220,7 @@ public class DataTypeManagerTest {
 
         final DataType tPerson = manager.from(mainItemDefinition).get();
 
-        assertEquals("uuid", tPerson.getUUID());
+        assertFalse(tPerson.getUUID().isEmpty());
         assertEquals("tPerson", tPerson.getName());
         assertEquals("Structure", tPerson.getType());
         assertEquals(3, tPerson.getSubDataTypes().size());
@@ -250,7 +244,7 @@ public class DataTypeManagerTest {
         verify(dataTypeStore).index(employee.getUUID(), employee);
         verify(dataTypeStore).index(company.getUUID(), company);
 
-        assertEquals("uuid", name.getUUID());
+        assertFalse(name.getUUID().isEmpty());
         assertEquals("name", name.getName());
         assertEquals("Text", name.getType());
         assertEquals("", name.getConstraint());
@@ -258,8 +252,9 @@ public class DataTypeManagerTest {
         assertEquals(0, name.getSubDataTypes().size());
         assertFalse(name.hasSubDataTypes());
         assertTrue(name.isList());
+        assertFalse(name.isReadOnly());
 
-        assertEquals("uuid", address.getUUID());
+        assertFalse(address.getUUID().isEmpty());
         assertEquals("address", address.getName());
         assertEquals("tAddress", address.getType());
         assertEquals("", address.getConstraint());
@@ -267,8 +262,9 @@ public class DataTypeManagerTest {
         assertEquals(1, address.getSubDataTypes().size());
         assertTrue(address.hasSubDataTypes());
         assertFalse(address.isList());
+        assertFalse(address.isReadOnly());
 
-        assertEquals("uuid", street.getUUID());
+        assertFalse(street.getUUID().isEmpty());
         assertEquals("street", street.getName());
         assertEquals("Text", street.getType());
         assertEquals("", street.getConstraint());
@@ -276,8 +272,9 @@ public class DataTypeManagerTest {
         assertEquals(0, street.getSubDataTypes().size());
         assertFalse(street.hasSubDataTypes());
         assertFalse(street.isList());
+        assertFalse(street.isReadOnly());
 
-        assertEquals("uuid", employee.getUUID());
+        assertFalse(employee.getUUID().isEmpty());
         assertEquals("employee", employee.getName());
         assertEquals("Structure", employee.getType());
         assertEquals("", employee.getConstraint());
@@ -285,8 +282,9 @@ public class DataTypeManagerTest {
         assertEquals(1, employee.getSubDataTypes().size());
         assertTrue(employee.hasSubDataTypes());
         assertFalse(employee.isList());
+        assertFalse(employee.isReadOnly());
 
-        assertEquals("uuid", company.getUUID());
+        assertFalse(company.getUUID().isEmpty());
         assertEquals("company", company.getName());
         assertEquals("Text", company.getType());
         assertEquals("\"Red\", \"Hat\"", company.getConstraint());
@@ -294,6 +292,28 @@ public class DataTypeManagerTest {
         assertEquals(0, company.getSubDataTypes().size());
         assertFalse(company.hasSubDataTypes());
         assertFalse(company.isList());
+        assertFalse(company.isReadOnly());
+    }
+
+    @Test
+    public void testMakeDataTypeFromItemDefinitionWithAnImportedItemDefinition() {
+
+        final ItemDefinition itemDefinition = mock(ItemDefinition.class);
+        final Name name = mock(Name.class);
+        final QName typeRefMock = mock(QName.class);
+
+        when(name.getValue()).thenReturn("id");
+        when(typeRefMock.getLocalPart()).thenReturn("string");
+        when(itemDefinition.getName()).thenReturn(name);
+        when(itemDefinition.getItemComponent()).thenReturn(new ArrayList<>());
+        when(itemDefinition.getTypeRef()).thenReturn(typeRefMock);
+        when(itemDefinition.isAllowOnlyVisualChange()).thenReturn(true);
+        when(itemDefinitionUtils.getConstraintText(any())).thenCallRealMethod();
+        when(itemDefinitionUtils.findByName(any())).thenReturn(Optional.empty());
+
+        final DataType dataType = manager.from(itemDefinition).get();
+
+        assertTrue(dataType.isReadOnly());
     }
 
     @Test
@@ -302,7 +322,7 @@ public class DataTypeManagerTest {
         final BuiltInType builtInType = BuiltInType.values()[0];
         final DataType dataType = manager.from(builtInType).get();
 
-        assertEquals("uuid", dataType.getUUID());
+        assertFalse(dataType.getUUID().isEmpty());
         assertEquals("--", dataType.getName());
         assertEquals("number", dataType.getType());
         assertEquals(emptyList(), dataType.getSubDataTypes());
@@ -314,7 +334,7 @@ public class DataTypeManagerTest {
 
         final DataType dataType = manager.fromNew().get();
 
-        assertEquals("uuid", dataType.getUUID());
+        assertFalse(dataType.getUUID().isEmpty());
         assertEquals("--", dataType.getName());
         assertEquals("Any", dataType.getType());
         assertEquals("", dataType.getConstraint());
@@ -399,9 +419,9 @@ public class DataTypeManagerTest {
         final List<String> subDataTypeStack = singletonList("type");
         final String expectedParentUUID = "expectedParentUUID";
 
-        doReturn(Optional.of(expectedParentUUID)).when(manager).getDataTypeUUID();
+        doReturn(expectedDataType).when(manager).getDataType();
         doReturn(manager).when(manager).anotherManager();
-        doReturn(manager).when(manager).newDataType();
+        doReturn(manager).when(manager).newDataType(anyBoolean());
         doReturn(manager).when(manager).withUUID();
         doReturn(manager).when(manager).withParentUUID(anyString());
         doReturn(manager).when(manager).withItemDefinition(any());
@@ -415,12 +435,13 @@ public class DataTypeManagerTest {
         doReturn(manager).when(manager).withIndexedItemDefinition();
         doReturn(subDataTypeStack).when(manager).getSubDataTypeStack();
         doReturn(expectedDataType).when(manager).get();
-        doReturn(expectedDataType).when(manager).get();
+        when(expectedDataType.isReadOnly()).thenReturn(false);
+        when(expectedDataType.getUUID()).thenReturn(expectedParentUUID);
 
         final DataType actualDataType = manager.createSubDataType(itemDefinition);
         final InOrder inOrder = Mockito.inOrder(manager);
 
-        inOrder.verify(manager).newDataType();
+        inOrder.verify(manager).newDataType(false);
         inOrder.verify(manager).withUUID();
         inOrder.verify(manager).withParentUUID(expectedParentUUID);
         inOrder.verify(manager).withItemDefinition(itemDefinition);
