@@ -36,14 +36,17 @@ import org.kie.workbench.common.dmn.api.definition.v1_1.Decision;
 import org.kie.workbench.common.dmn.api.property.dmn.Name;
 import org.kie.workbench.common.dmn.api.property.dmn.QName;
 import org.kie.workbench.common.dmn.client.commands.factory.canvas.SetComponentWidthCommand;
+import org.kie.workbench.common.dmn.client.commands.general.DeleteCellValueCommand;
 import org.kie.workbench.common.dmn.client.commands.general.DeleteHasNameCommand;
 import org.kie.workbench.common.dmn.client.commands.general.DeleteHeaderValueCommand;
+import org.kie.workbench.common.dmn.client.commands.general.SetCellValueCommand;
 import org.kie.workbench.common.dmn.client.commands.general.SetHasNameCommand;
 import org.kie.workbench.common.dmn.client.commands.general.SetHeaderValueCommand;
 import org.kie.workbench.common.dmn.client.commands.general.SetTypeRefCommand;
 import org.kie.workbench.common.dmn.client.editors.expressions.types.GridFactoryCommandUtils;
 import org.kie.workbench.common.dmn.client.editors.expressions.types.context.ExpressionCellValue;
 import org.kie.workbench.common.dmn.client.widgets.grid.columns.EditableHeaderMetaData;
+import org.kie.workbench.common.dmn.client.widgets.grid.columns.factory.ListBoxSingletonDOMElementFactory;
 import org.kie.workbench.common.dmn.client.widgets.grid.columns.factory.TextAreaSingletonDOMElementFactory;
 import org.kie.workbench.common.dmn.client.widgets.grid.columns.factory.TextBoxSingletonDOMElementFactory;
 import org.kie.workbench.common.dmn.client.widgets.grid.controls.HasCellEditorControls;
@@ -166,6 +169,11 @@ public class BaseExpressionGridGeneralTest extends BaseExpressionGridTest {
 
     private Decision decision = new Decision();
 
+    private interface MockHasCellEditorControlsHeaderMetaData extends HasCellEditorControls,
+                                                                      GridColumn.HeaderMetaData {
+
+    }
+
     @Override
     public void setup() {
         super.setup();
@@ -215,6 +223,7 @@ public class BaseExpressionGridGeneralTest extends BaseExpressionGridTest {
                                       cellEditorControls,
                                       listSelector,
                                       translationService,
+                                      false,
                                       0) {
             @Override
             protected BaseUIModelMapper makeUiModelMapper() {
@@ -227,18 +236,12 @@ public class BaseExpressionGridGeneralTest extends BaseExpressionGridTest {
             }
 
             @Override
-            protected void initialiseUiModel() {
+            public void initialiseUiRows() {
                 //Nothing for this test
             }
 
             @Override
-            public List<ListSelectorItem> getItems(final int uiRowIndex,
-                                                   final int uiColumnIndex) {
-                return Collections.emptyList();
-            }
-
-            @Override
-            public void onItemSelected(final ListSelectorItem item) {
+            public void initialiseUiCells() {
                 //Nothing for this test
             }
         };
@@ -672,6 +675,17 @@ public class BaseExpressionGridGeneralTest extends BaseExpressionGridTest {
         assertThat(factory.getHasValueCommand().apply(tupleWithValue)).isInstanceOf(SetHeaderValueCommand.class);
     }
 
+    @Test
+    public void testBodyListBoxFactory() {
+        appendColumns(GridColumn.class);
+        when(grid.getModel().getColumns().get(0).getHeaderMetaData()).thenReturn(Collections.singletonList(mock(EditableHeaderMetaData.class)));
+        when(mapper.getUiModel()).thenReturn(() -> grid.getModel());
+
+        final ListBoxSingletonDOMElementFactory factory = grid.getBodyListBoxFactory();
+        assertThat(factory.getHasNoValueCommand().apply(tupleWithoutValue)).isInstanceOf(DeleteCellValueCommand.class);
+        assertThat(factory.getHasValueCommand().apply(tupleWithValue)).isInstanceOf(SetCellValueCommand.class);
+    }
+
     @Test
     public void testClearDisplayNameConsumer() {
         doTestClearDisplayNameConsumer(false,
@@ -847,11 +861,51 @@ public class BaseExpressionGridGeneralTest extends BaseExpressionGridTest {
     }
 
     @Test
-    public void testShowContextMenu() {
-        final double columnWidth = 100.0;
+    @SuppressWarnings("unchecked")
+    public void testShowContextMenuHeader() {
+        final MockHasCellEditorControlsHeaderMetaData headerMetaData = mock(MockHasCellEditorControlsHeaderMetaData.class);
+        final HasCellEditorControls.Editor cellControlsEditorMock = mock(HasCellEditorControls.Editor.class);
+        doReturn(Optional.of(cellControlsEditorMock)).when(headerMetaData).getEditor();
+
+        grid.getModel().appendColumn(new BaseGridColumn<Object>(headerMetaData,
+                                                                mock(GridColumnRenderer.class),
+                                                                COLUMN_WIDTH));
+
+        assertThat(grid.showContextMenuForHeader(0, 0)).isTrue();
+
+        verify(cellControlsEditorMock).bind(eq(headerMetaData),
+                                            eq(0),
+                                            eq(0));
+        verify(cellEditorControls).show(eq(cellControlsEditorMock),
+                                        eq(Optional.empty()),
+                                        eq((int) COLUMN_WIDTH / 2),
+                                        eq((int) HEADER_HEIGHT / 2));
+    }
+
+    @Test
+    @SuppressWarnings("unchecked")
+    public void testShowContextMenuHeaderMissingEditor() {
+        final MockHasCellEditorControlsHeaderMetaData headerMetaData = mock(MockHasCellEditorControlsHeaderMetaData.class);
+        doReturn(Optional.empty()).when(headerMetaData).getEditor();
+
         grid.getModel().appendColumn(new BaseGridColumn<Object>(mock(GridColumn.HeaderMetaData.class),
                                                                 mock(GridColumnRenderer.class),
-                                                                columnWidth));
+                                                                COLUMN_WIDTH));
+
+        assertThat(grid.showContextMenuForHeader(0, 0)).isFalse();
+
+        verify(cellEditorControls, never()).show(any(HasCellEditorControls.Editor.class),
+                                                 any(Optional.class),
+                                                 anyInt(),
+                                                 anyInt());
+    }
+
+    @Test
+    @SuppressWarnings("unchecked")
+    public void testShowContextMenu() {
+        grid.getModel().appendColumn(new BaseGridColumn<Object>(mock(GridColumn.HeaderMetaData.class),
+                                                                mock(GridColumnRenderer.class),
+                                                                COLUMN_WIDTH));
         final BaseGridRow gridRow = new BaseGridRow();
         grid.getModel().appendRow(gridRow);
 
@@ -863,18 +917,21 @@ public class BaseExpressionGridGeneralTest extends BaseExpressionGridTest {
 
         assertThat(grid.showContextMenuForCell(0, 0)).isTrue();
 
+        verify(cellControlsEditorMock).bind(eq(grid),
+                                            eq(0),
+                                            eq(0));
         verify(cellEditorControls).show(eq(cellControlsEditorMock),
                                         eq(Optional.empty()),
-                                        eq((int) columnWidth / 2),
+                                        eq((int) COLUMN_WIDTH / 2),
                                         eq((int) (gridRow.getHeight() / 2 + HEADER_HEIGHT)));
     }
 
     @Test
+    @SuppressWarnings("unchecked")
     public void testShowContextMenuMissingEditor() {
-        final double columnWidth = 100.0;
         grid.getModel().appendColumn(new BaseGridColumn<Object>(mock(GridColumn.HeaderMetaData.class),
                                                                 mock(GridColumnRenderer.class),
-                                                                columnWidth));
+                                                                COLUMN_WIDTH));
         final BaseGridRow gridRow = new BaseGridRow();
         grid.getModel().appendRow(gridRow);
 
