@@ -16,9 +16,9 @@
 
 package org.kie.workbench.common.screens.library.client.screens.project;
 
+import java.util.Arrays;
 import java.util.HashMap;
 import java.util.Map;
-
 import javax.annotation.PostConstruct;
 import javax.enterprise.event.Event;
 import javax.inject.Inject;
@@ -35,15 +35,18 @@ import org.guvnor.common.services.project.service.GAVAlreadyExistsException;
 import org.jboss.errai.common.client.api.Caller;
 import org.jboss.errai.common.client.api.ErrorCallback;
 import org.jboss.errai.common.client.api.RemoteCallback;
+import org.jboss.errai.ui.client.local.spi.TranslationService;
 import org.kie.workbench.common.screens.library.api.LibraryInfo;
 import org.kie.workbench.common.screens.library.api.LibraryService;
 import org.kie.workbench.common.screens.library.api.preferences.LibraryPreferences;
+import org.kie.workbench.common.screens.library.client.resources.i18n.LibraryConstants;
 import org.kie.workbench.common.screens.library.client.util.LibraryPlaces;
 import org.kie.workbench.common.screens.projecteditor.client.util.KiePOMDefaultOptions;
 import org.kie.workbench.common.screens.projecteditor.client.wizard.POMBuilder;
 import org.kie.workbench.common.services.shared.validation.ValidationService;
 import org.kie.workbench.common.widgets.client.callbacks.CommandWithThrowableDrivenErrorCallback;
 import org.uberfire.client.mvp.UberElement;
+import org.uberfire.client.views.pfly.widgets.ErrorPopup;
 import org.uberfire.ext.widgets.common.client.common.BusyIndicatorView;
 import org.uberfire.ext.widgets.common.client.common.HasBusyIndicator;
 import org.uberfire.java.nio.file.FileAlreadyExistsException;
@@ -68,11 +71,11 @@ public class AddProjectPopUpPresenter {
         String getVersion();
 
         void setDescription(String description);
-
+        
         void setGroupId(String groupId);
-
+        
         void setArtifactId(String artifactId);
-
+        
         void setVersion(String version);
 
         boolean isAdvancedOptionsSelected();
@@ -107,7 +110,7 @@ public class AddProjectPopUpPresenter {
 
         void setAddButtonEnabled(boolean enabled);
     }
-
+    
     private Caller<LibraryService> libraryService;
 
     private BusyIndicatorView busyIndicatorView;
@@ -129,6 +132,10 @@ public class AddProjectPopUpPresenter {
 
     private Caller<ValidationService> validationService;
 
+    private ErrorPopup errorPopup;
+
+    private TranslationService translationService;
+
     LibraryInfo libraryInfo;
 
     ParameterizedCommand<WorkspaceProject> successCallback;
@@ -144,7 +151,9 @@ public class AddProjectPopUpPresenter {
                                     final Event<NewProjectEvent> newProjectEvent,
                                     final LibraryPreferences libraryPreferences,
                                     final ConflictingRepositoriesPopup conflictingRepositoriesPopup,
-                                    final Caller<ValidationService> validationService) {
+                                    final Caller<ValidationService> validationService,
+                                    final ErrorPopup errorPopup,
+                                    final TranslationService translationService) {
         this.libraryService = libraryService;
         this.busyIndicatorView = busyIndicatorView;
         this.notificationEvent = notificationEvent;
@@ -156,6 +165,8 @@ public class AddProjectPopUpPresenter {
         this.libraryPreferences = libraryPreferences;
         this.conflictingRepositoriesPopup = conflictingRepositoriesPopup;
         this.validationService = validationService;
+        this.errorPopup = errorPopup;
+        this.translationService = translationService;
     }
 
     @PostConstruct
@@ -168,7 +179,7 @@ public class AddProjectPopUpPresenter {
                 AddProjectPopUpPresenter.this.libraryInfo = libraryInfo;
             }
         }).getLibraryInfo(projectContext.getActiveOrganizationalUnit()
-                                  .orElseThrow(() -> new IllegalStateException("Cannot get library info without an active organizational unit.")));
+                                        .orElseThrow(() -> new IllegalStateException("Cannot get library info without an active organizational unit.")));
     }
 
     public void setSuccessCallback(ParameterizedCommand<WorkspaceProject> successCallback) {
@@ -179,8 +190,8 @@ public class AddProjectPopUpPresenter {
         libraryPreferences.load(loadedLibraryPreferences -> {
                                     view.setDescription(loadedLibraryPreferences.getProjectPreferences().getDescription());
                                     view.setVersion(loadedLibraryPreferences.getProjectPreferences().getVersion());
-                                    view.setGroupId(projectContext.getActiveOrganizationalUnit().isPresent() ? projectContext.getActiveOrganizationalUnit().get().getDefaultGroupId()
-                                                            : loadedLibraryPreferences.getOrganizationalUnitPreferences().getGroupId());
+                                    view.setGroupId(projectContext.getActiveOrganizationalUnit().isPresent() ? projectContext.getActiveOrganizationalUnit().get().getDefaultGroupId() 
+                                                                                                             : loadedLibraryPreferences.getOrganizationalUnitPreferences().getGroupId());
                                     view.show();
                                 },
                                 error -> {
@@ -199,7 +210,7 @@ public class AddProjectPopUpPresenter {
         final String groupId = view.getGroupId();
         final String artifactId = view.getArtifactId();
         final String version = view.getVersion();
-
+        
         validateFields(name,
                        groupId,
                        artifactId,
@@ -209,15 +220,23 @@ public class AddProjectPopUpPresenter {
                                endProjectCreation();
                                getSuccessCallback().execute(project);
                            };
-                           final ErrorCallback<?> errorCallback = getErrorCallback();
+
+                           Map<Class<? extends Throwable>, CommandWithThrowableDrivenErrorCallback.CommandWithThrowable> errors = new HashMap<Class<? extends Throwable>, CommandWithThrowableDrivenErrorCallback.CommandWithThrowable>() {{
+                               put(GAVAlreadyExistsException.class, exception -> handleGAVAlreadyExistsException((GAVAlreadyExistsException) exception));
+                               put(FileAlreadyExistsException.class, exception -> handleFileExistsException((FileAlreadyExistsException) exception));
+                           }};
+
+                           final ErrorCallback<?> errorCallback = new CommandWithThrowableDrivenErrorCallback(busyIndicatorView, errors, throwable -> handleUnexpectedException(name, throwable));
+
                            final POM pom = setDefaultPOM(groupId,
                                                          artifactId,
                                                          version,
-                                                         name,
+                                                         name, 
                                                          description);
+
                            libraryService.call((WorkspaceProject project) -> successCallback.execute(project),
                                                errorCallback).createProject(projectContext.getActiveOrganizationalUnit()
-                                                                                    .orElseThrow(() -> new IllegalStateException("Cannot create new project without an active organizational unit.")),
+                                                                                          .orElseThrow(() -> new IllegalStateException("Cannot create new project without an active organizational unit.")),
                                                                             pom,
                                                                             mode);
                        });
@@ -345,34 +364,27 @@ public class AddProjectPopUpPresenter {
         };
     }
 
-    private ErrorCallback<?> getErrorCallback() {
-
-        Map<Class<? extends Throwable>, CommandWithThrowableDrivenErrorCallback.CommandWithThrowable> errors = new HashMap<Class<? extends Throwable>, CommandWithThrowableDrivenErrorCallback.CommandWithThrowable>() {{
-            put(GAVAlreadyExistsException.class,
-                parameter -> {
-                    GAVAlreadyExistsException exception = (GAVAlreadyExistsException) parameter;
-                    endProjectCreation();
-                    conflictingRepositoriesPopup.setContent(exception.getGAV(),
-                                                            ((GAVAlreadyExistsException) parameter).getRepositories(),
-                                                            () -> {
-                                                                conflictingRepositoriesPopup.hide();
-                                                                createProject(DeploymentMode.FORCED);
-                                                            });
-                    conflictingRepositoriesPopup.show();
-                });
-            put(FileAlreadyExistsException.class,
-                parameter -> {
-                    endProjectCreation();
-                    view.showError(view.getDuplicatedProjectMessage());
-                });
-        }};
-
-        return createErrorCallback(errors);
+    private void handleGAVAlreadyExistsException(final GAVAlreadyExistsException exception) {
+        endProjectCreation();
+        conflictingRepositoriesPopup.setContent(exception.getGAV(),
+                                                exception.getRepositories(),
+                                                () -> {
+                                                    conflictingRepositoriesPopup.hide();
+                                                    createProject(DeploymentMode.FORCED);
+                                                });
+        conflictingRepositoriesPopup.show();
     }
 
-    ErrorCallback<?> createErrorCallback(Map<Class<? extends Throwable>, CommandWithThrowableDrivenErrorCallback.CommandWithThrowable> errors) {
-        return new CommandWithThrowableDrivenErrorCallback(busyIndicatorView,
-                                                           errors);
+    private void handleUnexpectedException(final String project, final Throwable throwable) {
+        view.hide();
+        endProjectCreation();
+        busyIndicatorView.hideBusyIndicator();
+        errorPopup.showError(translationService.format(LibraryConstants.ErrorCreatingPoject, project), Arrays.toString(throwable.getStackTrace()));
+    }
+
+    private void handleFileExistsException(final FileAlreadyExistsException exception) {
+        endProjectCreation();
+        view.showError(view.getDuplicatedProjectMessage());
     }
 
     boolean isDuplicatedProjectName(Throwable throwable) {
@@ -395,28 +407,32 @@ public class AddProjectPopUpPresenter {
         view.hide();
     }
 
-    public void restoreDefaultAdvancedOptions() {
-        libraryPreferences.load(loadedLibraryPreferences -> {
-                                    view.setDescription(loadedLibraryPreferences.getProjectPreferences().getDescription());
-                                    view.setVersion(loadedLibraryPreferences.getProjectPreferences().getVersion());
-                                    view.setGroupId(projectContext.getActiveOrganizationalUnit().isPresent() ? projectContext.getActiveOrganizationalUnit().get().getDefaultGroupId()
-                                                            : loadedLibraryPreferences.getOrganizationalUnitPreferences().getGroupId());
-                                },
-                                error -> {
-                                });
+    public void setDefaultArtifactId() {
+        view.setArtifactId(view.getName().replaceAll(" ", ""));
     }
-
+    
+    public void restoreAdvancedOptions() {
+        libraryPreferences.load(loadedLibraryPreferences -> {
+            view.setVersion(loadedLibraryPreferences.getProjectPreferences().getVersion());
+            setDefaultArtifactId();
+            view.setGroupId(projectContext.getActiveOrganizationalUnit().isPresent() ? projectContext.getActiveOrganizationalUnit().get().getDefaultGroupId() 
+                                                                                     : loadedLibraryPreferences.getOrganizationalUnitPreferences().getGroupId());
+        },
+        error -> {
+        });
+    }
+    
     private POM setDefaultPOM(String groupId, String artifactId, String version, String name, String description) {
         final POM pom = new POM(new GAV(groupId,
                                         artifactId,
                                         version));
         pom.setName(name);
         pom.setDescription(description);
-
+        
         POMBuilder pomBuilder = new POMBuilder(pom);
         KiePOMDefaultOptions pomDefaultOptions = new KiePOMDefaultOptions();
         pomBuilder.setBuildPlugins(pomDefaultOptions.getBuildPlugins());
-
+        
         return pomBuilder.build();
     }
 }
