@@ -15,8 +15,6 @@
  */
 package org.kie.workbench.common.screens.library.client.screens;
 
-import java.util.ArrayList;
-import java.util.List;
 import java.util.Optional;
 
 import org.guvnor.common.services.project.client.context.WorkspaceProjectContext;
@@ -24,12 +22,9 @@ import org.guvnor.common.services.project.client.security.ProjectController;
 import org.guvnor.common.services.project.events.NewProjectEvent;
 import org.guvnor.common.services.project.model.WorkspaceProject;
 import org.guvnor.structure.client.security.OrganizationalUnitController;
-import org.guvnor.structure.events.AfterEditOrganizationalUnitEvent;
 import org.guvnor.structure.organizationalunit.OrganizationalUnit;
-import org.guvnor.structure.organizationalunit.OrganizationalUnitService;
 import org.guvnor.structure.repositories.Repository;
 import org.guvnor.structure.repositories.RepositoryRemovedEvent;
-import org.jboss.errai.common.client.api.Caller;
 import org.jboss.errai.common.client.dom.HTMLElement;
 import org.jboss.errai.ioc.client.api.ManagedInstance;
 import org.junit.Before;
@@ -40,7 +35,6 @@ import org.kie.workbench.common.screens.library.client.screens.importrepository.
 import org.kie.workbench.common.screens.library.client.screens.organizationalunit.contributors.tab.ContributorsListPresenter;
 import org.kie.workbench.common.screens.library.client.screens.organizationalunit.contributors.tab.SpaceContributorsListServiceImpl;
 import org.kie.workbench.common.screens.library.client.screens.organizationalunit.delete.DeleteOrganizationalUnitPopUpPresenter;
-import org.kie.workbench.common.screens.library.client.util.LibraryPermissions;
 import org.kie.workbench.common.screens.library.client.util.LibraryPlaces;
 import org.mockito.Mock;
 import org.mockito.runners.MockitoJUnitRunner;
@@ -60,7 +54,10 @@ public class LibraryScreenTest {
     private ManagedInstance<DeleteOrganizationalUnitPopUpPresenter> deleteOrganizationalUnitPopUpPresenters;
 
     @Mock
-    private LibraryPermissions libraryPermissions;
+    private ProjectController projectController;
+
+    @Mock
+    private OrganizationalUnitController organizationalUnitController;
 
     @Mock
     private EmptyLibraryScreen emptyLibraryScreen;
@@ -83,10 +80,6 @@ public class LibraryScreenTest {
     @Mock
     private LibraryPlaces libraryPlaces;
 
-    @Mock
-    private OrganizationalUnitService organizationalUnitService;
-    private Caller<OrganizationalUnitService> organizationalUnitServiceCaller;
-
     @Mock
     private SpaceContributorsListServiceImpl spaceContributorsListService;
 
@@ -103,14 +96,13 @@ public class LibraryScreenTest {
 
     @Before
     public void setup() {
-        organizationalUnitServiceCaller = new CallerMock<>(organizationalUnitService);
 
         doReturn(deleteOrganizationalUnitPopUpPresenter).when(deleteOrganizationalUnitPopUpPresenters).get();
         doReturn(orgUnitsMetricsView).when(orgUnitsMetricsScreen).getView();
 
-        doReturn(true).when(libraryPermissions).userCanCreateProject(any());
-        doReturn(true).when(libraryPermissions).userCanUpdateOrganizationalUnit(any());
-        doReturn(true).when(libraryPermissions).userCanDeleteOrganizationalUnit(any());
+        doReturn(true).when(projectController).canCreateProjects(any());
+        doReturn(true).when(organizationalUnitController).canUpdateOrgUnit(any());
+        doReturn(true).when(organizationalUnitController).canDeleteOrgUnit(any());
 
         doReturn(mock(PopulatedLibraryScreen.View.class)).when(populatedLibraryScreen).getView();
         doReturn(mock(EmptyLibraryScreen.View.class)).when(emptyLibraryScreen).getView();
@@ -130,14 +122,14 @@ public class LibraryScreenTest {
         libraryScreen = spy(new LibraryScreen(view,
                                               deleteOrganizationalUnitPopUpPresenters,
                                               projectContext,
-                                              libraryPermissions,
+                                              projectController,
+                                              organizationalUnitController,
                                               emptyLibraryScreen,
                                               populatedLibraryScreen,
                                               orgUnitsMetricsScreen,
                                               contributorsListPresenter,
                                               new CallerMock<>(libraryService),
                                               libraryPlaces,
-                                              organizationalUnitServiceCaller,
                                               spaceContributorsListService));
     }
 
@@ -151,7 +143,8 @@ public class LibraryScreenTest {
 
         verify(view).init(libraryScreen);
         verify(view).setTitle("name");
-        verify(contributorsListPresenter).setup(eq(spaceContributorsListService), any());
+        verify(contributorsListPresenter).setup(eq(spaceContributorsListService),
+                                                any());
     }
 
     @Test
@@ -163,7 +156,7 @@ public class LibraryScreenTest {
 
     @Test
     public void trySamplesWithoutPermissionTest() {
-        doReturn(false).when(libraryPermissions).userCanCreateProject(any());
+        doReturn(false).when(projectController).canCreateProjects(any());
 
         libraryScreen.trySamples();
 
@@ -180,7 +173,7 @@ public class LibraryScreenTest {
 
     @Test
     public void importProjectWithoutPermissionTest() {
-        doReturn(false).when(libraryPermissions).userCanCreateProject(any());
+        doReturn(false).when(projectController).canCreateProjects(any());
 
         libraryScreen.importProject();
 
@@ -197,7 +190,7 @@ public class LibraryScreenTest {
 
     @Test
     public void deleteWithoutPermissionTest() {
-        doReturn(false).when(libraryPermissions).userCanDeleteOrganizationalUnit(any());
+        doReturn(false).when(organizationalUnitController).canDeleteOrgUnit(any());
 
         libraryScreen.delete();
 
@@ -207,6 +200,7 @@ public class LibraryScreenTest {
 
     @Test
     public void showProjectsTest() {
+        doReturn(true).when(view).isProjectsTabActive();
         doReturn(true).when(libraryService).hasProjects(any());
         final HTMLElement populatedLibraryScreenElement = mock(HTMLElement.class);
         when(populatedLibraryScreen.getView().getElement()).thenReturn(populatedLibraryScreenElement);
@@ -270,6 +264,7 @@ public class LibraryScreenTest {
 
     @Test
     public void showNoProjectsTest() {
+        doReturn(true).when(view).isProjectsTabActive();
         doReturn(false).when(libraryService).hasProjects(any());
         final HTMLElement emptyLibraryScreenElement = mock(HTMLElement.class);
         when(emptyLibraryScreen.getView().getElement()).thenReturn(emptyLibraryScreenElement);
@@ -277,11 +272,13 @@ public class LibraryScreenTest {
         libraryScreen.showProjects();
 
         verify(view).updateContent(emptyLibraryScreenElement);
-        verify(view).setProjectsCount(0);
+        verify(view,
+               times(2)).setProjectsCount(0);
     }
 
     @Test
     public void showMetrics() {
+        doReturn(true).when(view).isMetricsTabActive();
         libraryScreen.showMetrics();
         verify(orgUnitsMetricsScreen).refresh();
         verify(view).updateContent(any());
