@@ -27,17 +27,21 @@ import org.guvnor.common.services.project.model.POM;
 import org.guvnor.common.services.project.model.WorkspaceProject;
 import org.guvnor.common.services.project.service.DeploymentMode;
 import org.guvnor.structure.organizationalunit.OrganizationalUnit;
+import org.jboss.errai.ui.client.local.spi.TranslationService;
 import org.junit.Before;
 import org.junit.Test;
 import org.junit.runner.RunWith;
 import org.kie.workbench.common.screens.library.api.LibraryInfo;
 import org.kie.workbench.common.screens.library.api.LibraryService;
+import org.kie.workbench.common.screens.library.api.preferences.LibraryOrganizationalUnitPreferences;
 import org.kie.workbench.common.screens.library.api.preferences.LibraryPreferences;
+import org.kie.workbench.common.screens.library.api.preferences.LibraryProjectPreferences;
 import org.kie.workbench.common.screens.library.client.util.LibraryPlaces;
 import org.kie.workbench.common.services.shared.validation.ValidationService;
 import org.mockito.ArgumentCaptor;
 import org.mockito.Mock;
 import org.mockito.runners.MockitoJUnitRunner;
+import org.uberfire.client.views.pfly.widgets.ErrorPopup;
 import org.uberfire.ext.widgets.common.client.common.BusyIndicatorView;
 import org.uberfire.java.nio.file.FileAlreadyExistsException;
 import org.uberfire.mocks.CallerMock;
@@ -48,6 +52,7 @@ import org.uberfire.workbench.events.NotificationEvent;
 
 import static org.jgroups.util.Util.assertEquals;
 import static org.mockito.Mockito.*;
+import static org.uberfire.mocks.ParametrizedCommandMock.executeParametrizedCommandWith;
 
 @RunWith(MockitoJUnitRunner.class)
 public class AddProjectPopUpPresenterTest {
@@ -86,6 +91,12 @@ public class AddProjectPopUpPresenterTest {
     private ValidationService validationService;
     private CallerMock<ValidationService> validationServiceCaller;
 
+    @Mock
+    private ErrorPopup errorPopup;
+
+    @Mock
+    private TranslationService translationService;
+
     private AddProjectPopUpPresenter presenter;
 
     private LibraryInfo libraryInfo;
@@ -116,7 +127,9 @@ public class AddProjectPopUpPresenterTest {
                                                      newProjectEvent,
                                                      libraryPreferences,
                                                      conflictingRepositoriesPopup,
-                                                     validationServiceCaller));
+                                                     validationServiceCaller,
+                                                     errorPopup,
+                                                     translationService));
 
         doReturn("baseUrl").when(presenter).getBaseURL();
 
@@ -196,13 +209,13 @@ public class AddProjectPopUpPresenterTest {
         assertEquals("groupId", pom.getGav().getGroupId());
         assertEquals("artifactId", pom.getGav().getArtifactId());
         assertEquals("version", pom.getGav().getVersion());
-
+        
         //Checking default kie-server options
         assertEquals("kjar", pom.getPackaging());
         assertEquals("org.kie", pom.getBuild().getPlugins().get(0).getGroupId());
         assertEquals("kie-maven-plugin", pom.getBuild().getPlugins().get(0).getArtifactId());
     }
-
+    
     @Test
     public void newWorkbenchProjectWithQuickSettingsIsCreated() throws Exception {
         final OrganizationalUnit organizationalUnit = mock(OrganizationalUnit.class);
@@ -224,7 +237,7 @@ public class AddProjectPopUpPresenterTest {
                                              pomArgumentCaptor.capture(),
                                              eq(DeploymentMode.VALIDATED));
         verify(view).setAddButtonEnabled(true);
-
+        
         final POM pom = pomArgumentCaptor.getValue();
 
         assertEquals("test", pom.getName());
@@ -232,7 +245,7 @@ public class AddProjectPopUpPresenterTest {
         assertEquals("groupId", pom.getGav().getGroupId());
         assertEquals("artifactId", pom.getGav().getArtifactId());
         assertEquals("version", pom.getGav().getVersion());
-
+        
         //Checking default kie-server options
         assertEquals("kjar", pom.getPackaging());
         assertEquals("org.kie", pom.getBuild().getPlugins().get(0).getGroupId());
@@ -281,6 +294,27 @@ public class AddProjectPopUpPresenterTest {
         verify(view).setAddButtonEnabled(true);
     }
 
+    @Test
+    public void testCreateProjectWithUnexpectedError() {
+        doReturn("test").when(view).getName();
+        doReturn("description").when(view).getDescription();
+
+        doThrow(new IllegalStateException("New repository should always have a branch."))
+                .when(libraryService).createProject(any(), any(), any());
+
+        presenter.add();
+
+        verify(view).hide();
+        verify(view).setAddButtonEnabled(true);
+        verify(view).hideBusyIndicator();
+
+        verify(busyIndicatorView).hideBusyIndicator();
+
+        verify(errorPopup).showError(anyString(), anyString());
+
+        verify(translationService).format(anyString(), anyString());
+    }
+
     @Test
     public void createProjectWithEmptyNameFailedTest() {
         doReturn("").when(view).getName();
@@ -481,6 +515,7 @@ public class AddProjectPopUpPresenterTest {
         verify(view).setAddButtonEnabled(true);
     }
 
+
     @Test
     public void createProjectWithExternalSuccessCallbackTest() {
         doReturn("test").when(view).getName();
@@ -495,4 +530,50 @@ public class AddProjectPopUpPresenterTest {
         verify(view).setAddButtonEnabled(true);
         verify(command).execute(any());
     }
+
+    @Test
+    public void testRestoreAdvancedOptionsWithActiveOrganizationalUnit() {
+        LibraryPreferences loadedLibraryPreferences = mock(LibraryPreferences.class);
+        LibraryProjectPreferences libraryProjectPreferences = mock(LibraryProjectPreferences.class);
+
+        doReturn(libraryProjectPreferences).when(loadedLibraryPreferences).getProjectPreferences();
+        doReturn("version").when(libraryProjectPreferences).getVersion();
+        when(projectContext.getActiveOrganizationalUnit().get().getDefaultGroupId()).thenReturn("group");
+        when(view.getName()).thenReturn("Project Test");
+
+        executeParametrizedCommandWith(0, loadedLibraryPreferences).when(libraryPreferences).load(any(ParameterizedCommand.class),
+                                                                                                  any(ParameterizedCommand.class));
+
+        presenter.restoreAdvancedOptions();
+
+        verify(libraryPreferences).load(any(ParameterizedCommand.class), any(ParameterizedCommand.class));
+        verify(view).setVersion("version");
+        verify(view).setGroupId("group");
+        verify(view, never()).setDescription(any());
+        verify(view).setArtifactId("ProjectTest");
+    }
+
+    @Test
+    public void testRestoreAdvancedOptionsWithoutActiveOrganizationalUnit() {
+        LibraryPreferences loadedLibraryPreferences = mock(LibraryPreferences.class);
+        LibraryProjectPreferences libraryProjectPreferences = mock(LibraryProjectPreferences.class);
+        LibraryOrganizationalUnitPreferences libraryOrganizationalUnitPreferences = mock(LibraryOrganizationalUnitPreferences.class);
+
+        doReturn(libraryProjectPreferences).when(loadedLibraryPreferences).getProjectPreferences();
+        doReturn("version").when(libraryProjectPreferences).getVersion();
+        doReturn(libraryOrganizationalUnitPreferences).when(loadedLibraryPreferences).getOrganizationalUnitPreferences();
+        when(libraryOrganizationalUnitPreferences.getGroupId()).thenReturn("group");
+        when(projectContext.getActiveOrganizationalUnit()).thenReturn(Optional.empty());
+        when(view.getName()).thenReturn("Project Test");
+
+        executeParametrizedCommandWith(0, loadedLibraryPreferences).when(libraryPreferences).load(any(ParameterizedCommand.class),
+                                                                                                  any(ParameterizedCommand.class));
+
+        presenter.restoreAdvancedOptions();
+
+        verify(view).setVersion("version");
+        verify(view).setGroupId("group");
+        verify(view, never()).setDescription(any());
+        verify(view).setArtifactId("ProjectTest");
+    }
 }
