@@ -29,14 +29,11 @@ import org.junit.runner.RunWith;
 import org.kie.server.api.model.KieContainerStatus;
 import org.kie.server.api.model.Message;
 import org.kie.server.api.model.ReleaseId;
+import org.kie.server.controller.api.model.events.ServerInstanceUpdated;
 import org.kie.server.controller.api.model.runtime.Container;
+import org.kie.server.controller.api.model.runtime.ServerInstance;
 import org.kie.server.controller.api.model.runtime.ServerInstanceKey;
-import org.kie.server.controller.api.model.spec.Capability;
-import org.kie.server.controller.api.model.spec.ContainerConfig;
-import org.kie.server.controller.api.model.spec.ContainerSpec;
-import org.kie.server.controller.api.model.spec.ProcessConfig;
-import org.kie.server.controller.api.model.spec.RuleConfig;
-import org.kie.server.controller.api.model.spec.ServerTemplateKey;
+import org.kie.server.controller.api.model.spec.*;
 import org.kie.workbench.common.screens.server.management.client.container.config.process.ContainerProcessConfigPresenter;
 import org.kie.workbench.common.screens.server.management.client.container.config.rules.ContainerRulesConfigPresenter;
 import org.kie.workbench.common.screens.server.management.client.container.status.ContainerRemoteStatusPresenter;
@@ -45,6 +42,7 @@ import org.kie.workbench.common.screens.server.management.client.events.Containe
 import org.kie.workbench.common.screens.server.management.client.events.RefreshRemoteServers;
 import org.kie.workbench.common.screens.server.management.client.events.ServerTemplateSelected;
 import org.kie.workbench.common.screens.server.management.client.util.State;
+import org.kie.workbench.common.screens.server.management.model.ContainerRuntimeOperation;
 import org.kie.workbench.common.screens.server.management.model.ContainerSpecData;
 import org.kie.workbench.common.screens.server.management.model.ContainerUpdateEvent;
 import org.kie.workbench.common.screens.server.management.service.RuntimeManagementService;
@@ -158,6 +156,29 @@ public class ContainerPresenterTest {
         containers = new ArrayList<Container>();
         containerSpecData = new ContainerSpecData(containerSpec,
                                                   containers);
+
+        presenter.setContainerSpec(containerSpec);
+    }
+
+    @Test
+    public void testOnInstanceUpdatedWhenContainerSpecIsNull() {
+        ServerInstanceUpdated serverInstanceUpdated = mock(ServerInstanceUpdated.class);
+        ContainerSpec containerSpec = null;
+        presenter.setContainerSpec(containerSpec);
+        presenter.onInstanceUpdated(serverInstanceUpdated);
+
+        verify(runtimeManagementService, times(0)).getContainersByContainerSpec(any(), any());
+    }
+
+    @Test
+    public void testOnInstanceUpdatedWhenContainerSpecServerTemplateNotEqualServerInstanceUpdatedServerTemplate() {
+        ServerInstanceUpdated serverInstanceUpdated = mock(ServerInstanceUpdated.class);
+        ServerInstance serverInstance = mock(ServerInstance.class);
+        when(serverInstanceUpdated.getServerInstance()).thenReturn(serverInstance);
+        when(serverInstance.getServerTemplateId()).thenReturn(serverTemplateKey + "1");
+        presenter.onInstanceUpdated(serverInstanceUpdated);
+
+        verify(runtimeManagementService, times(0)).getContainersByContainerSpec(any(), any());
     }
 
     @Test
@@ -181,6 +202,7 @@ public class ContainerPresenterTest {
         verify(view).setContainerStartState(State.ENABLED);
         verify(view).setContainerStopState(State.DISABLED);
         verify(view).disableRemoveButton();
+        verify(view).enableToggleActivationButton();
 
         final String errorMessage = "ERROR";
         when(view.getStartContainerErrorMessage()).thenReturn(errorMessage);
@@ -221,6 +243,57 @@ public class ContainerPresenterTest {
         verify(view).setContainerStopState(State.DISABLED);
         verify(view).disableRemoveButton();
     }
+    
+    @Test
+    public void testDeactivateContainerFromStopedState() {
+        presenter.loadContainers(containerSpecData);
+
+        presenter.toggleActivationContainer();
+
+        verify(view).setContainerStartState(State.DISABLED);
+        verify(view).setContainerStopState(State.ENABLED);
+        verify(view).enableRemoveButton();
+        verify(view).disableToggleActivationButton();
+    }
+    
+    @Test
+    public void testDeactivateContainerFromStartedState() {
+        presenter.loadContainers(containerSpecData);
+        
+        presenter.startContainer();
+        containerSpec.setStatus(KieContainerStatus.STARTED);
+       
+        verify(view).enableToggleActivationButton();
+
+        presenter.toggleActivationContainer();
+
+        verify(view,
+                times(2)).enableToggleActivationButton();
+        verify(view).updateToggleActivationButton(eq(true));
+    }
+    
+    @Test
+    public void testDeactivateThenActivateContainerFromStartedState() {
+        presenter.loadContainers(containerSpecData);
+        
+        presenter.startContainer();
+        containerSpec.setStatus(KieContainerStatus.STARTED);
+       
+        verify(view).enableToggleActivationButton();
+
+        presenter.toggleActivationContainer();
+        verify(view,
+                times(2)).enableToggleActivationButton();
+        verify(view).updateToggleActivationButton(eq(true));
+        
+        presenter.toggleActivationContainer();
+
+        verify(view,
+                times(3)).enableToggleActivationButton();
+        verify(view,times(2)).updateToggleActivationButton(eq(false));
+
+
+    }
 
     @Test
     public void testLoadContainersEmpty() {
@@ -230,6 +303,30 @@ public class ContainerPresenterTest {
                    1);
     }
 
+    @Test
+    public void testLoadContainersOnlyOnSelectedContainerEvent() {
+
+        ContainerSpec containerSpec1 = new ContainerSpec("containerId1",
+                                                         "containerName",
+                                                         serverTemplateKey,
+                                                         releaseId,
+                                                         KieContainerStatus.STOPPED,
+                                                         new HashMap<Capability, ContainerConfig>());
+        presenter.setContainerSpec(containerSpec1);
+        presenter.loadContainers(containerSpecData);
+
+        verifyLoad(true,
+                   0);
+
+        presenter.setContainerSpec(containerSpec);
+        presenter.loadContainers(containerSpecData);
+
+        verifyLoad(true,
+                   1);
+
+    }
+
+
     @Test
     public void testRefresh() {
         when(runtimeManagementService.getContainersByContainerSpec(
@@ -333,8 +430,41 @@ public class ContainerPresenterTest {
     }
 
     @Test
-    public void testRefreshOnContainerUpdateEvent() {
-        final ContainerUpdateEvent updateEvent = mock(ContainerUpdateEvent.class);
+    public void testRefreshOnContainerUpdateEventWhenRuntimeOperationIsNotStopContainer() {
+        final ContainerUpdateEvent updateEvent = new ContainerUpdateEvent(null,
+                                                                          containerSpec,
+                                                                          null,
+                                                                          null,
+                                                                          ContainerRuntimeOperation.START_CONTAINER);
+        doNothing().when(presenter).refresh();
+
+        presenter.refreshOnContainerUpdateEvent(updateEvent);
+
+        verify(presenter).refresh();
+    }
+
+    @Test
+    public void testRefreshOnContainerUpdateEventWhenRuntimeOperationIsStopContainer() {
+        final ContainerUpdateEvent updateEvent = new ContainerUpdateEvent(null,
+                                                                          containerSpec,
+                                                                          null,
+                                                                          null,
+                                                                          ContainerRuntimeOperation.STOP_CONTAINER);
+        doNothing().when(presenter).refresh();
+
+        presenter.refreshOnContainerUpdateEvent(updateEvent);
+
+        verify(presenter,
+               never()).refresh();
+    }
+
+    @Test
+    public void testRefreshOnContainerUpdateEventWithSameContainerSpec() {
+        final ContainerUpdateEvent updateEvent = new ContainerUpdateEvent(null,
+                                                                          containerSpec,
+                                                                          null,
+                                                                          null,
+                                                                          ContainerRuntimeOperation.START_CONTAINER);
 
         doNothing().when(presenter).refresh();
 
@@ -343,6 +473,24 @@ public class ContainerPresenterTest {
         verify(presenter).refresh();
     }
 
+    @Test
+    public void testRefreshOnContainerUpdateEventWithDifferentContainerSpec() {
+        final ContainerSpec containerSpecEvent = new ContainerSpec();
+        containerSpecEvent.setReleasedId(new ReleaseId("org",
+                                                       "kie",
+                                                       "1.0"));
+        final ContainerUpdateEvent updateEvent = new ContainerUpdateEvent(null,
+                                                                          containerSpecEvent,
+                                                                          null,
+                                                                          null,
+                                                                          ContainerRuntimeOperation.START_CONTAINER);
+
+        presenter.refreshOnContainerUpdateEvent(updateEvent);
+
+        verify(presenter,
+               never()).refresh();
+    }
+
     @Test
     public void testOnRefresh() {
         when(runtimeManagementService.getContainersByContainerSpec(
@@ -399,4 +547,55 @@ public class ContainerPresenterTest {
         verify(serverTemplateSelectedEvent,
                times(2)).fire(new ServerTemplateSelected(containerSpec.getServerTemplateKey()));
     }
-}
\ No newline at end of file
+
+    @Test //Test fix for GUVNOR-3579
+    public void testLoadWhenRuntimeManagementServiceReturnsInvalidData() {
+        ContainerSpecData badData = new ContainerSpecData(null, null);
+        when(runtimeManagementService.getContainersByContainerSpec(anyObject(), anyObject())).thenReturn(badData);
+
+        ContainerSpecKey lookupKey = new ContainerSpecKey("dummyId", "dummyName", new ServerTemplateKey("keyId", "keyName"));
+
+        presenter.load(lookupKey); // Doesn't throw NPE when ContainerSpecData contain nulls
+
+        verify(view, never()).setContainerName(anyString());
+    }
+
+    @Test //Test fix for JBPM-8028
+    public void testUpdateStatusForStopped() {
+        presenter.updateStatus(KieContainerStatus.STOPPED);
+
+        verify(view).updateToggleActivationButton(false);
+    }
+
+    @Test //Test fix for JBPM-8028
+    public void testUpdateStatusForStarted() {
+        presenter.updateStatus(KieContainerStatus.STARTED);
+
+        verify(view).disableRemoveButton();
+        verify(view).setContainerStartState(State.ENABLED);
+        verify(view).setContainerStopState(State.DISABLED);
+        verify(view).updateToggleActivationButton(false);
+        verify(view).enableToggleActivationButton();
+    }
+
+    @Test //Test fix for JBPM-8028 DEACTIVATED
+    public void testUpdateStatusForFailed() {
+        presenter.updateStatus(KieContainerStatus.FAILED);
+
+        verify(view).enableRemoveButton();
+        verify(view).setContainerStartState(State.DISABLED);
+        verify(view).setContainerStopState(State.ENABLED);
+        verify(view).disableToggleActivationButton();
+    }
+
+    @Test //Test fix for JBPM-8028 DEACTIVATED
+    public void testUpdateStatusForDeactiveated() {
+        presenter.updateStatus(KieContainerStatus.DEACTIVATED);
+
+        verify(view).disableRemoveButton();
+        verify(view).setContainerStartState(State.ENABLED);
+        verify(view).setContainerStopState(State.DISABLED);
+        verify(view).updateToggleActivationButton(true);
+        verify(view).enableToggleActivationButton();
+    }
+}
