@@ -5,7 +5,7 @@
  * you may not use this file except in compliance with the License.
  * You may obtain a copy of the License at
  *
- *   http://www.apache.org/licenses/LICENSE-2.0
+ *     http://www.apache.org/licenses/LICENSE-2.0
  *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
@@ -19,6 +19,7 @@ package org.kie.workbench.common.stunner.core.lookup.rule;
 import org.kie.workbench.common.stunner.core.lookup.LookupManager;
 import org.kie.workbench.common.stunner.core.rule.Rule;
 
-public interface RuleLookupManager extends LookupManager<Rule, RuleLookupRequest> {
+public interface RuleLookupManager
+        extends LookupManager<Rule, RuleLookupRequest> {
 
 }
