@@ -34,13 +34,13 @@ import org.kie.workbench.common.stunner.lienzo.toolbox.grid.Point2DGrid;
 import org.kie.workbench.common.stunner.lienzo.toolbox.items.DecoratedItem;
 import org.mockito.ArgumentCaptor;
 import org.mockito.Mock;
-import org.uberfire.mvp.Command;
 
 import static org.junit.Assert.assertEquals;
 import static org.junit.Assert.assertFalse;
 import static org.mockito.Matchers.any;
 import static org.mockito.Matchers.eq;
 import static org.mockito.Mockito.doAnswer;
+import static org.mockito.Mockito.doReturn;
 import static org.mockito.Mockito.mock;
 import static org.mockito.Mockito.never;
 import static org.mockito.Mockito.spy;
@@ -61,17 +61,14 @@ public class ToolboxImplTest {
                                                             100d,
                                                             200d);
     @Mock
-    private BiConsumer<Group, Command> showExecutor;
+    private BiConsumer<Group, Runnable> showExecutor;
 
     @Mock
-    private BiConsumer<Group, Command> hideExecutor;
+    private BiConsumer<Group, Runnable> hideExecutor;
 
     @Mock
     private ItemGridImpl wrapped;
 
-    @Mock
-    private Group group;
-
     @Mock
     private IPrimitive primitive;
 
@@ -79,30 +76,32 @@ public class ToolboxImplTest {
     private BoundingPoints boundingPoints;
 
     private ToolboxImpl tested;
+    private Group group;
 
     @Before
     @SuppressWarnings("unchecked")
     public void setUp() {
+        group = spy(new Group());
         when(wrapped.getBoundingBox()).thenReturn(() -> boundingBox);
-        when(wrapped.onRefresh(any(Command.class))).thenReturn(wrapped);
+        when(wrapped.onRefresh(any(Runnable.class))).thenReturn(wrapped);
         when(wrapped.asPrimitive()).thenReturn(group);
         when(wrapped.getPrimitive()).thenReturn(primitive);
-        when(group.getAlpha()).thenReturn(0d);
-        when(group.getComputedBoundingPoints()).thenReturn(boundingPoints);
-        when(group.getBoundingBox()).thenReturn(boundingBox);
         when(boundingPoints.getBoundingBox()).thenReturn(boundingBox);
+        doReturn(0d).when(group).getAlpha();
+        doReturn(boundingPoints).when(group).getComputedBoundingPoints();
+        doReturn(boundingBox).when(group).getBoundingBox();
         doAnswer(invocationOnMock -> {
-            ((Command) invocationOnMock.getArguments()[0]).execute();
-            ((Command) invocationOnMock.getArguments()[1]).execute();
+            ((Runnable) invocationOnMock.getArguments()[0]).run();
+            ((Runnable) invocationOnMock.getArguments()[1]).run();
             return wrapped;
-        }).when(wrapped).show(any(Command.class),
-                              any(Command.class));
+        }).when(wrapped).show(any(Runnable.class),
+                              any(Runnable.class));
         doAnswer(invocationOnMock -> {
-            ((Command) invocationOnMock.getArguments()[0]).execute();
-            ((Command) invocationOnMock.getArguments()[1]).execute();
+            ((Runnable) invocationOnMock.getArguments()[0]).run();
+            ((Runnable) invocationOnMock.getArguments()[1]).run();
             return wrapped;
-        }).when(wrapped).hide(any(Command.class),
-                              any(Command.class));
+        }).when(wrapped).hide(any(Runnable.class),
+                              any(Runnable.class));
         tested = new ToolboxImpl(() -> shapeBoundingBox,
                                  wrapped)
                 .useHideExecutor(hideExecutor)
@@ -133,6 +132,13 @@ public class ToolboxImplTest {
                      tested.getAt());
     }
 
+    @Test
+    public void testAtButVisible() {
+        makeItVisible();
+        tested.at(Direction.EAST);
+        verifyGroupIsOnTop();
+    }
+
     @Test
     public void testOffset() {
         Point2D o = new Point2D(50,
@@ -144,6 +150,13 @@ public class ToolboxImplTest {
                      tested.getOffset());
     }
 
+    @Test
+    public void testOffsetButVisible() {
+        makeItVisible();
+        tested.offset(new Point2D(50d, 25d));
+        verifyGroupIsOnTop();
+    }
+
     @Test
     public void testGrid() {
         Point2DGrid grid = mock(Point2DGrid.class);
@@ -155,6 +168,15 @@ public class ToolboxImplTest {
                times(1)).grid(eq(grid));
     }
 
+    @Test
+    public void testGridButVisible() {
+        makeItVisible();
+        Point2DGrid grid = mock(Point2DGrid.class);
+        when(wrapped.getGrid()).thenReturn(grid);
+        tested.grid(grid);
+        verifyGroupIsOnTop();
+    }
+
     @Test
     public void testUpdateGridSize() {
         AutoGrid grid = spy(new AutoGrid.Builder()
@@ -191,23 +213,24 @@ public class ToolboxImplTest {
 
     @Test
     public void testShow() {
-        final Command before = mock(Command.class);
-        final Command after = mock(Command.class);
+        final Runnable before = mock(Runnable.class);
+        final Runnable after = mock(Runnable.class);
         tested.show(before,
                     after);
         verify(wrapped,
-               times(1)).show(any(Command.class),
-                              any(Command.class));
+               times(1)).show(any(Runnable.class),
+                              any(Runnable.class));
         verify(wrapped,
-               never()).hide(any(Command.class),
-                             any(Command.class));
+               never()).hide(any(Runnable.class),
+                             any(Runnable.class));
         verify(before,
-               times(1)).execute();
+               times(1)).run();
         verify(after,
-               times(1)).execute();
+               times(1)).run();
         ArgumentCaptor<Point2D> pc = ArgumentCaptor.forClass(Point2D.class);
         verify(group,
                times(1)).setLocation(pc.capture());
+        verifyGroupIsOnTop();
         Point2D point = pc.getValue();
         assertEquals(33d,
                      point.getX(),
@@ -219,20 +242,24 @@ public class ToolboxImplTest {
 
     @Test
     public void testHide() {
-        final Command before = mock(Command.class);
-        final Command after = mock(Command.class);
+        final Runnable before = mock(Runnable.class);
+        final Runnable after = mock(Runnable.class);
         tested.hide(before,
                     after);
         verify(wrapped,
                times(1)).hide(eq(before),
-                              any(Command.class));
+                              any(Runnable.class));
         verify(wrapped,
-               never()).show(any(Command.class),
-                             any(Command.class));
+               never()).show(any(Runnable.class),
+                             any(Runnable.class));
+        verify(group, never()).moveToTop();
+        verify(group, never()).moveToBottom();
+        verify(group, never()).moveDown();
+        verify(group, never()).moveUp();
         verify(before,
-               times(1)).execute();
+               times(1)).run();
         verify(after,
-               times(1)).execute();
+               times(1)).run();
     }
 
     @Test
@@ -241,4 +268,15 @@ public class ToolboxImplTest {
         verify(wrapped,
                times(1)).destroy();
     }
+
+    private void makeItVisible() {
+        doReturn(true).when(wrapped).isVisible();
+    }
+
+    private void verifyGroupIsOnTop() {
+        verify(group, times(1)).moveToTop();
+        verify(group, never()).moveToBottom();
+        verify(group, never()).moveDown();
+        verify(group, never()).moveUp();
+    }
 }
