@@ -23,7 +23,6 @@ import org.kie.workbench.common.stunner.bpmn.backend.converters.fromstunner.prop
 import org.kie.workbench.common.stunner.bpmn.definition.BaseReusableSubprocess;
 import org.kie.workbench.common.stunner.bpmn.definition.property.general.BPMNGeneralSet;
 import org.kie.workbench.common.stunner.bpmn.definition.property.task.BaseReusableSubprocessTaskExecutionSet;
-import org.kie.workbench.common.stunner.bpmn.definition.property.task.ReusableSubprocessTaskExecutionSet;
 import org.kie.workbench.common.stunner.core.graph.Node;
 import org.kie.workbench.common.stunner.core.graph.content.view.View;
 
@@ -59,16 +58,13 @@ public class ReusableSubprocessConverter {
 
         p.setAssignmentsInfo(definition.getDataIOSet().getAssignmentsinfo());
 
-        if (executionSet instanceof ReusableSubprocessTaskExecutionSet) {
-            ReusableSubprocessTaskExecutionSet reusableExecutionSet = (ReusableSubprocessTaskExecutionSet) executionSet;
-            if (Boolean.TRUE.equals(reusableExecutionSet.getIsMultipleInstance().getValue())) {
-                p.setIsSequential(reusableExecutionSet.getMultipleInstanceExecutionMode().isSequential());
-                p.setCollectionInput(reusableExecutionSet.getMultipleInstanceCollectionInput().getValue());
-                p.setInput(reusableExecutionSet.getMultipleInstanceDataInput().getValue());
-                p.setCollectionOutput(reusableExecutionSet.getMultipleInstanceCollectionOutput().getValue());
-                p.setOutput(reusableExecutionSet.getMultipleInstanceDataOutput().getValue());
-                p.setCompletionCondition(reusableExecutionSet.getMultipleInstanceCompletionCondition().getValue());
-            }
+        if (Boolean.TRUE.equals(executionSet.getIsMultipleInstance().getValue())) {
+            p.setIsSequential(executionSet.getMultipleInstanceExecutionMode().isSequential());
+            p.setCollectionInput(executionSet.getMultipleInstanceCollectionInput().getValue());
+            p.setInput(executionSet.getMultipleInstanceDataInput().getValue());
+            p.setCollectionOutput(executionSet.getMultipleInstanceCollectionOutput().getValue());
+            p.setOutput(executionSet.getMultipleInstanceDataOutput().getValue());
+            p.setCompletionCondition(executionSet.getMultipleInstanceCompletionCondition().getValue());
         }
 
         p.setSimulationSet(definition.getSimulationSet());
