@@ -21,6 +21,7 @@ import java.util.List;
 
 import org.eclipse.bpmn2.BaseElement;
 import org.eclipse.bpmn2.Documentation;
+import org.eclipse.bpmn2.Interface;
 import org.eclipse.bpmn2.ItemDefinition;
 import org.eclipse.bpmn2.RootElement;
 import org.eclipse.bpmn2.di.BPMNEdge;
@@ -45,6 +46,7 @@ public abstract class BasePropertyWriter {
     protected final VariableScope variableScope;
     protected final List<ItemDefinition> itemDefinitions = new ArrayList<>();
     protected final List<RootElement> rootElements = new ArrayList<>();
+    protected final List<Interface> interfaces = new ArrayList<>();
     protected BPMNShape shape;
 
     public BasePropertyWriter(BaseElement baseElement, VariableScope variableScope) {
@@ -56,6 +58,10 @@ public abstract class BasePropertyWriter {
         return this.baseElement.getId();
     }
 
+    public void setId(String id) {
+        baseElement.setId(id);
+    }
+
     protected void setBounds(Bounds rect) {
         this.shape = di.createBPMNShape();
         shape.setId(Ids.bpmnShape(getId()));
@@ -124,6 +130,10 @@ public abstract class BasePropertyWriter {
         this.itemDefinitions.add(itemDefinition);
     }
 
+    protected void addInterfaceDefinition(Interface iface) {
+        this.interfaces.add(iface);
+    }
+
     protected void addRootElement(RootElement rootElement) {
         this.rootElements.add(rootElement);
     }
@@ -136,6 +146,10 @@ public abstract class BasePropertyWriter {
         return rootElements;
     }
 
+    public List<Interface> getInterfaces() {
+        return interfaces;
+    }
+
     public static org.kie.workbench.common.stunner.core.graph.content.Bounds absoluteBounds(final Node<? extends View, ?> node) {
         final Point2D point2D = GraphUtils.getComputedPosition(node);
         final org.kie.workbench.common.stunner.core.graph.content.Bounds bounds = node.getContent().getBounds();
