@@ -17,7 +17,6 @@
 package org.kie.workbench.common.stunner.bpmn.backend.service.diagram.marshalling.events;
 
 import org.junit.Test;
-import org.kie.workbench.common.stunner.bpmn.backend.service.diagram.marshalling.Marshaller;
 import org.kie.workbench.common.stunner.bpmn.definition.StartSignalEvent;
 import org.kie.workbench.common.stunner.bpmn.definition.property.event.signal.InterruptingSignalEventExecutionSet;
 import org.kie.workbench.common.stunner.core.diagram.Diagram;
@@ -27,7 +26,7 @@ import org.kie.workbench.common.stunner.core.graph.Graph;
 import static org.junit.Assert.assertEquals;
 import static org.junit.Assert.assertNotNull;
 
-public class StartSignalEventTest extends StartEvent<StartSignalEvent> {
+public class StartSignalEventTest extends StartEventTest<StartSignalEvent> {
 
     private static final String BPMN_START_EVENT_FILE_PATH = "org/kie/workbench/common/stunner/bpmn/backend/service/diagram/signalStartEvents.bpmn";
 
@@ -40,10 +39,6 @@ public class StartSignalEventTest extends StartEvent<StartSignalEvent> {
 
     private static final int AMOUNT_OF_NODES_IN_DIAGRAM = 11;
 
-    public StartSignalEventTest(Marshaller marshallerType) {
-        super(marshallerType);
-    }
-
     @Test
     @Override
     public void testUnmarshallTopLevelEventFilledProperties() throws Exception {
