@@ -17,7 +17,6 @@
 package org.kie.workbench.common.stunner.bpmn.backend.service.diagram.marshalling.events;
 
 import org.junit.Test;
-import org.kie.workbench.common.stunner.bpmn.backend.service.diagram.marshalling.Marshaller;
 import org.kie.workbench.common.stunner.bpmn.definition.StartTimerEvent;
 import org.kie.workbench.common.stunner.bpmn.definition.property.event.timer.InterruptingTimerEventExecutionSet;
 import org.kie.workbench.common.stunner.core.diagram.Diagram;
@@ -28,7 +27,7 @@ import static org.junit.Assert.assertEquals;
 import static org.junit.Assert.assertNotNull;
 import static org.junit.Assert.assertNull;
 
-public class StartTimerEventTest extends StartEvent<StartTimerEvent> {
+public class StartTimerEventTest extends StartEventTest<StartTimerEvent> {
 
     private static final String BPMN_START_EVENT_FILE_PATH = "org/kie/workbench/common/stunner/bpmn/backend/service/diagram/timerStartEvents.bpmn";
 
@@ -45,10 +44,6 @@ public class StartTimerEventTest extends StartEvent<StartTimerEvent> {
 
     private static final int AMOUNT_OF_NODES_IN_DIAGRAM = 21;
 
-    public StartTimerEventTest(Marshaller marshallerType) {
-        super(marshallerType);
-    }
-
     @Test
     @Override
     public void testUnmarshallTopLevelEventFilledProperties() throws Exception {
