@@ -17,7 +17,6 @@
 package org.kie.workbench.common.stunner.bpmn.backend.service.diagram.marshalling.events.intermediate;
 
 import org.junit.Test;
-import org.kie.workbench.common.stunner.bpmn.backend.service.diagram.marshalling.Marshaller;
 import org.kie.workbench.common.stunner.bpmn.definition.IntermediateEscalationEvent;
 import org.kie.workbench.common.stunner.bpmn.definition.property.event.escalation.CancellingEscalationEventExecutionSet;
 import org.kie.workbench.common.stunner.core.diagram.Diagram;
@@ -27,7 +26,7 @@ import org.kie.workbench.common.stunner.core.graph.Graph;
 import static org.junit.Assert.assertEquals;
 import static org.junit.Assert.assertNotNull;
 
-public class BoundaryCatchingIntermediateEscalationEventTest extends BoundaryCatchingIntermediateEvent<IntermediateEscalationEvent> {
+public class BoundaryCatchingIntermediateEscalationEventTest extends BoundaryCatchingIntermediateEventTest<IntermediateEscalationEvent> {
 
     private static final String BPMN_CATCHING_INTERMEDIATE_EVENT_FILE_PATH = "org/kie/workbench/common/stunner/bpmn/backend/service/diagram/boundaryEscalationEvents.bpmn";
 
@@ -45,10 +44,6 @@ public class BoundaryCatchingIntermediateEscalationEventTest extends BoundaryCat
 
     private static final int AMOUNT_OF_NODES_IN_DIAGRAM = 25;
 
-    public BoundaryCatchingIntermediateEscalationEventTest(Marshaller marshallerType) {
-        super(marshallerType);
-    }
-
     @Test
     @Override
     public void testUnmarshallTopLevelEventFilledProperties() throws Exception {
