@@ -19,7 +19,6 @@ package org.kie.workbench.common.stunner.bpmn.backend.service.diagram.marshallin
 import java.util.List;
 
 import org.junit.Test;
-import org.kie.workbench.common.stunner.bpmn.backend.service.diagram.marshalling.Marshaller;
 import org.kie.workbench.common.stunner.bpmn.definition.MultipleInstanceSubprocess;
 import org.kie.workbench.common.stunner.bpmn.definition.property.task.MultipleInstanceSubprocessTaskExecutionSet;
 import org.kie.workbench.common.stunner.bpmn.definition.property.task.ScriptTypeValue;
@@ -28,9 +27,8 @@ import org.kie.workbench.common.stunner.core.diagram.Metadata;
 import org.kie.workbench.common.stunner.core.graph.Graph;
 
 import static org.assertj.core.api.Assertions.assertThat;
-import static org.junit.Assume.assumeFalse;
 
-public class MultipleInstanceSubProcessTest extends SubProcess<MultipleInstanceSubprocess> {
+public class MultipleInstanceSubProcessTest extends SubProcessTest<MultipleInstanceSubprocess> {
 
     private static final String BPMN_SUB_PROCESS_FILE_PATH = "org/kie/workbench/common/stunner/bpmn/backend/service/diagram/multipleInstanceSubProcesses.bpmn";
 
@@ -80,68 +78,10 @@ public class MultipleInstanceSubProcessTest extends SubProcess<MultipleInstanceS
             "System.out.println(\"`&(^*&^(\\n\\r\");\n" +
             "Object o = kcontext.getVariable(\"hello_world\");";
 
-    private static Diagram<Graph, Metadata> oldDiagram;
-    private static Diagram<Graph, Metadata> oldRoundTripDiagram;
-
-    private static Diagram<Graph, Metadata> newDiagram;
-    private static Diagram<Graph, Metadata> newRoundTripDiagram;
-
-    public MultipleInstanceSubProcessTest(Marshaller marshallerType) throws Exception {
-        super(marshallerType, marshallers());
-    }
-
-    @Override
-    Diagram<Graph, Metadata> getNewDiagram() {
-        return newDiagram;
-    }
-
-    @Override
-    void setNewDiagram(Diagram<Graph, Metadata> diagram) {
-        newDiagram = diagram;
-    }
-
-    @Override
-    Diagram<Graph, Metadata> getNewRoundTripDiagram() {
-        return newRoundTripDiagram;
-    }
-
-    @Override
-    void setNewRoundTripDiagram(Diagram<Graph, Metadata> diagram) {
-        newRoundTripDiagram = diagram;
-    }
-
-    @Override
-    Diagram<Graph, Metadata> getOldDiagram() {
-        return oldDiagram;
-    }
-
-    @Override
-    void setOldDiagram(Diagram<Graph, Metadata> diagram) {
-        oldDiagram = diagram;
-    }
-
-    @Override
-    Diagram<Graph, Metadata> getOldRoundTripDiagram() {
-        return oldRoundTripDiagram;
-    }
-
-    @Override
-    void setOldRoundTripDiagram(Diagram<Graph, Metadata> diagram) {
-        oldRoundTripDiagram = diagram;
+    public MultipleInstanceSubProcessTest() throws Exception {
     }
 
     @Test
-    @Override
-    public void testMarshallTopLevelFilledPropertiesSubProcess() {
-        final String ignoreMessage = "There is a bug in old marshaller. Once, the bug is fixed, the " +
-                "method should be removed only from this class, not from its superclass.\n" +
-                "For more information see https://issues.jboss.org/browse/JBPM-8467";
-        assumeFalse(ignoreMessage, isCurrentMarshallerOld());
-        super.testMarshallTopLevelFilledPropertiesSubProcess();
-    }
-
-    @Test
-    @Override
     public void testUnmarshallTopLevelEmptyPropertiesSubProcess() {
         Diagram<Graph, Metadata> diagram = getDiagram();
         assertDiagram(diagram, AMOUNT_OF_NODES_IN_DIAGRAM);
@@ -167,7 +107,6 @@ public class MultipleInstanceSubProcessTest extends SubProcess<MultipleInstanceS
     }
 
     @Test
-    @Override
     public void testUnmarshallTopLevelFilledPropertiesSubProcess() {
         final String SUB_PROCESS_NAME_JAVA = "Multiple Instance sub-process01 name ~!@#$%^&*()_+`1234567890-={}|[]\\:\";'<>?,./";
         final String SUB_PROCESS_DOCUMENTATION_JAVA = "Multiple Instance sub-process01 doc\n ~!@#$%^&*()_+`1234567890-={}|[]\\:\";'<>?,./";
@@ -242,7 +181,6 @@ public class MultipleInstanceSubProcessTest extends SubProcess<MultipleInstanceS
     }
 
     @Test
-    @Override
     public void testUnmarshallTopLevelSubProcessWithEdges() {
         final String SUB_PROCESS_NAME = "Multiple Instance Sub-process07";
 
@@ -270,7 +208,6 @@ public class MultipleInstanceSubProcessTest extends SubProcess<MultipleInstanceS
     }
 
     @Test
-    @Override
     public void testUnmarshallSubProcessLevelEmptyPropertiesSubProcess() {
         Diagram<Graph, Metadata> diagram = getDiagram();
         assertDiagram(diagram, AMOUNT_OF_NODES_IN_DIAGRAM);
@@ -296,7 +233,6 @@ public class MultipleInstanceSubProcessTest extends SubProcess<MultipleInstanceS
     }
 
     @Test
-    @Override
     public void testUnmarshallSubProcessLevelFilledPropertiesSubProcess() {
         final String SUB_PROCESS_NAME_JAVA = "Multiple Instance sub-process04 name ~!@#$%^&*()_+`1234567890-={}|[]\\:\";'<>?,./";
         final String SUB_PROCESS_DOCUMENTATION_JAVA = "Multiple Instance sub-process04 doc\n ~!@#$%^&*()_+`1234567890-={}|[]\\:\";'<>?,./";
@@ -371,7 +307,6 @@ public class MultipleInstanceSubProcessTest extends SubProcess<MultipleInstanceS
     }
 
     @Test
-    @Override
     public void testUnmarshallSubProcessLevelSubProcessWithEdges() {
         final String SUB_PROCESS_NAME = "Multiple Instance Sub-process08";
 
