@@ -17,14 +17,15 @@
 package org.kie.workbench.common.stunner.bpmn.client.forms.fields.variablesEditor;
 
 import java.util.ArrayList;
+import java.util.EnumSet;
 import java.util.HashMap;
 import java.util.List;
 import java.util.Map;
+import java.util.Set;
 
 import javax.enterprise.context.Dependent;
 import javax.inject.Inject;
 
-import com.google.gwt.user.client.ui.IsWidget;
 import org.kie.workbench.common.forms.dynamic.client.rendering.FieldRenderer;
 import org.kie.workbench.common.forms.dynamic.client.rendering.formGroups.FormGroup;
 import org.kie.workbench.common.forms.dynamic.client.rendering.formGroups.impl.def.DefaultFormGroup;
@@ -34,36 +35,43 @@ import org.kie.workbench.common.stunner.bpmn.client.forms.fields.model.Variable;
 import org.kie.workbench.common.stunner.bpmn.client.forms.fields.model.VariableRow;
 import org.kie.workbench.common.stunner.bpmn.client.forms.util.ListBoxValues;
 import org.kie.workbench.common.stunner.bpmn.client.forms.util.StringUtils;
+import org.kie.workbench.common.stunner.bpmn.client.util.VariableUtils;
 import org.kie.workbench.common.stunner.bpmn.forms.model.VariablesEditorFieldDefinition;
-import org.kie.workbench.common.stunner.core.client.api.AbstractClientSessionManager;
+import org.kie.workbench.common.stunner.core.client.api.SessionManager;
+import org.kie.workbench.common.stunner.core.diagram.Diagram;
 import org.kie.workbench.common.stunner.core.graph.Graph;
+import org.uberfire.backend.vfs.Path;
 import org.uberfire.client.workbench.widgets.common.ErrorPopupPresenter;
 
+import static org.kie.workbench.common.stunner.bpmn.client.util.VariableUtils.FindVariableUsagesFlag;
+import static org.kie.workbench.common.stunner.bpmn.client.util.VariableUtils.FindVariableUsagesFlag.CASE_FILE_VARIABLE;
+
 @Dependent
 public class VariablesEditorFieldRenderer extends FieldRenderer<VariablesEditorFieldDefinition, DefaultFormGroup>
         implements VariablesEditorWidgetView.Presenter {
 
-    private final AbstractClientSessionManager sessionManager;
-    private final BPMNProcessVariableDeleteHandler deleteHandler;
+    private final SessionManager sessionManager;
     Map<String, String> mapDataTypeNamesToDisplayNames = null;
     Map<String, String> mapDataTypeDisplayNamesToNames = null;
     ListBoxValues dataTypeListBoxValues;
     private VariablesEditorWidgetView view;
     private Variable.VariableType variableType = Variable.VariableType.PROCESS;
-    private List<String> dataTypes = new ArrayList<String>();
-    private List<String> dataTypeDisplayNames = new ArrayList<String>();
+    private List<String> dataTypes = new ArrayList<>();
     private Graph graph;
+    private Path path;
 
-    @Inject
-    private ErrorPopupPresenter errorPopupPresenter;
+    private Set<FindVariableUsagesFlag> findVariableUsagesFlags;
+
+    private final ErrorPopupPresenter errorPopupPresenter;
 
     @Inject
     public VariablesEditorFieldRenderer(final VariablesEditorWidgetView variablesEditor,
-                                        AbstractClientSessionManager sessionManager,
-                                        final BPMNProcessVariableDeleteHandler deleteHandler) {
+                                        final SessionManager sessionManager,
+                                        final ErrorPopupPresenter errorPopupPresenter) {
         this.view = variablesEditor;
         this.sessionManager = sessionManager;
-        this.deleteHandler = deleteHandler;
+        this.errorPopupPresenter = errorPopupPresenter;
+        this.findVariableUsagesFlags = EnumSet.noneOf(FindVariableUsagesFlag.class);
     }
 
     @Override
@@ -76,15 +84,23 @@ public class VariablesEditorFieldRenderer extends FieldRenderer<VariablesEditorF
         DefaultFormGroup formGroup = formGroupsInstance.get();
 
         view.init(this);
-        graph = sessionManager.getCurrentSession().getCanvasHandler().getDiagram().getGraph();
+
+        final Diagram diagram = sessionManager.getCurrentSession().getCanvasHandler().getDiagram();
+        path = diagram.getMetadata().getPath();
+        graph = diagram.getGraph();
 
         formGroup.render(view.asWidget(), field);
 
+        if (field != null && field.isCaseFileVariable()) {
+            findVariableUsagesFlags = EnumSet.of(CASE_FILE_VARIABLE);
+        }
+
         return formGroup;
     }
 
+    @Override
     protected void setReadOnly(final boolean readOnly) {
-
+        view.setReadOnly(readOnly);
     }
 
     @Override
@@ -115,7 +131,6 @@ public class VariablesEditorFieldRenderer extends FieldRenderer<VariablesEditorF
     public void setDataTypes(final List<String> dataTypes,
                              final List<String> dataTypeDisplayNames) {
         this.dataTypes = dataTypes;
-        this.dataTypeDisplayNames = dataTypeDisplayNames;
         this.mapDataTypeNamesToDisplayNames = createMapDataTypeNamesToDisplayNames(dataTypes,
                                                                                    dataTypeDisplayNames);
         this.mapDataTypeDisplayNamesToNames = createMapDataTypeDisplayNamesToNames(dataTypes,
@@ -129,7 +144,7 @@ public class VariablesEditorFieldRenderer extends FieldRenderer<VariablesEditorF
 
     private Map<String, String> createMapDataTypeNamesToDisplayNames(final List<String> dataTypes,
                                                                      final List<String> dataTypeDisplayNames) {
-        Map<String, String> mapDataTypeNamesToDisplayNames = new HashMap<String, String>();
+        Map<String, String> mapDataTypeNamesToDisplayNames = new HashMap<>();
         for (int i = 0; i < dataTypeDisplayNames.size(); i++) {
             mapDataTypeNamesToDisplayNames.put(dataTypes.get(i),
                                                dataTypeDisplayNames.get(i));
@@ -139,7 +154,7 @@ public class VariablesEditorFieldRenderer extends FieldRenderer<VariablesEditorF
 
     private Map<String, String> createMapDataTypeDisplayNamesToNames(final List<String> dataTypes,
                                                                      final List<String> dataTypeDisplayNames) {
-        Map<String, String> mapDataTypeDisplayNamesToNames = new HashMap<String, String>();
+        Map<String, String> mapDataTypeDisplayNamesToNames = new HashMap<>();
         for (int i = 0; i < dataTypes.size(); i++) {
             mapDataTypeDisplayNamesToNames.put(dataTypeDisplayNames.get(i),
                                                dataTypes.get(i));
@@ -154,7 +169,7 @@ public class VariablesEditorFieldRenderer extends FieldRenderer<VariablesEditorF
 
     @Override
     public List<VariableRow> deserializeVariables(final String s) {
-        List<VariableRow> variableRows = new ArrayList<VariableRow>();
+        List<VariableRow> variableRows = new ArrayList<>();
         if (s != null && !s.isEmpty()) {
             String[] vs = s.split(",");
             for (String v : vs) {
@@ -174,7 +189,7 @@ public class VariablesEditorFieldRenderer extends FieldRenderer<VariablesEditorF
 
     @Override
     public String serializeVariables(final List<VariableRow> variableRows) {
-        List<Variable> variables = new ArrayList<Variable>();
+        List<Variable> variables = new ArrayList<>();
         for (VariableRow row : variableRows) {
             if (row.getName() != null && row.getName().length() > 0) {
                 variables.add(new Variable(row,
@@ -189,6 +204,7 @@ public class VariablesEditorFieldRenderer extends FieldRenderer<VariablesEditorF
      * @param name
      * @return
      */
+    @Override
     public boolean isDuplicateName(final String name) {
         if (name == null || name.trim().isEmpty()) {
             return false;
@@ -210,10 +226,15 @@ public class VariablesEditorFieldRenderer extends FieldRenderer<VariablesEditorF
         return false;
     }
 
+    @Override
+    public boolean isBoundToNodes(String name) {
+        return VariableUtils.findVariableUsages(graph, name, findVariableUsagesFlags).size() > 0;
+    }
+
+    @Override
     public void removeVariable(final VariableRow variableRow) {
 
-        if (deleteHandler.isVariableBoundToNodes(graph,
-                                                 variableRow.getName())) {
+        if (isBoundToNodes(variableRow.getName())) {
             errorPopupPresenter.showMessage(StunnerFormsClientFieldsConstants.INSTANCE.DeleteDiagramVariableError());
         } else {
             view.getVariableRows().remove(variableRow);
@@ -223,14 +244,17 @@ public class VariablesEditorFieldRenderer extends FieldRenderer<VariablesEditorF
 
     @Override
     public ListBoxValues.ValueTester dataTypesTester() {
-        return new ListBoxValues.ValueTester() {
-            public String getNonCustomValueForUserString(String dataTypeDisplayName) {
-                if (mapDataTypeNamesToDisplayNames != null && mapDataTypeNamesToDisplayNames.containsKey(dataTypeDisplayName)) {
-                    return mapDataTypeNamesToDisplayNames.get(dataTypeDisplayName);
-                } else {
-                    return null;
-                }
+        return dataTypeDisplayName -> {
+            if (mapDataTypeNamesToDisplayNames != null && mapDataTypeNamesToDisplayNames.containsKey(dataTypeDisplayName)) {
+                return mapDataTypeNamesToDisplayNames.get(dataTypeDisplayName);
+            } else {
+                return null;
             }
         };
     }
+
+    @Override
+    public Path getDiagramPath() {
+        return path;
+    }
 }
