@@ -51,8 +51,10 @@ import org.kie.workbench.common.stunner.bpmn.definition.EndMessageEvent;
 import org.kie.workbench.common.stunner.bpmn.definition.EndNoneEvent;
 import org.kie.workbench.common.stunner.bpmn.definition.EndSignalEvent;
 import org.kie.workbench.common.stunner.bpmn.definition.EndTerminateEvent;
+import org.kie.workbench.common.stunner.bpmn.definition.EventGateway;
 import org.kie.workbench.common.stunner.bpmn.definition.EventSubprocess;
 import org.kie.workbench.common.stunner.bpmn.definition.ExclusiveGateway;
+import org.kie.workbench.common.stunner.bpmn.definition.GenericServiceTask;
 import org.kie.workbench.common.stunner.bpmn.definition.InclusiveGateway;
 import org.kie.workbench.common.stunner.bpmn.definition.IntermediateCompensationEvent;
 import org.kie.workbench.common.stunner.bpmn.definition.IntermediateCompensationEventThrowing;
@@ -157,6 +159,9 @@ public class BPMNShapeFactory
                 .delegate(NoneTask.class,
                           new TaskShapeDef(),
                           () -> svgShapeFactory)
+                .delegate(GenericServiceTask.class,
+                          new TaskShapeDef(),
+                          () -> svgShapeFactory)
                 .delegate(UserTask.class,
                           new TaskShapeDef(),
                           () -> svgShapeFactory)
@@ -202,6 +207,9 @@ public class BPMNShapeFactory
                 .delegate(InclusiveGateway.class,
                           new GatewayShapeDef(),
                           () -> svgShapeFactory)
+                .delegate(EventGateway.class,
+                          new GatewayShapeDef(),
+                          () -> svgShapeFactory)
                 .delegate(Lane.class,
                           new LaneShapeDef(),
                           () -> svgShapeFactory)
