@@ -48,6 +48,7 @@ import org.kie.workbench.common.stunner.bpmn.definition.EndMessageEvent;
 import org.kie.workbench.common.stunner.bpmn.definition.EndNoneEvent;
 import org.kie.workbench.common.stunner.bpmn.definition.EndSignalEvent;
 import org.kie.workbench.common.stunner.bpmn.definition.EndTerminateEvent;
+import org.kie.workbench.common.stunner.bpmn.definition.EventGateway;
 import org.kie.workbench.common.stunner.bpmn.definition.EventSubprocess;
 import org.kie.workbench.common.stunner.bpmn.definition.ExclusiveGateway;
 import org.kie.workbench.common.stunner.bpmn.definition.InclusiveGateway;
@@ -218,6 +219,10 @@ public class BPMNShapeFactoryTest {
                times(1)).delegate(eq(InclusiveGateway.class),
                                   any(GatewayShapeDef.class),
                                   factoryArgumentCaptor.capture());
+        verify(delegateShapeFactory,
+               times(1)).delegate(eq(EventGateway.class),
+                                  any(GatewayShapeDef.class),
+                                  factoryArgumentCaptor.capture());
         verify(delegateShapeFactory,
                times(1)).delegate(eq(Lane.class),
                                   any(LaneShapeDef.class),
@@ -345,7 +350,7 @@ public class BPMNShapeFactoryTest {
         final long basicFactoryCallCount = factoryArgumentCaptor.getAllValues().stream()
                 .filter(this::isBasicShapeFactory)
                 .count();
-        assertEquals(40,
+        assertEquals(41,
                      svgFactoryCallCount,
                      0);
         assertEquals(2,
